<?php

namespace App\Console\Commands;

use Illuminate\Console\Command;
use Illuminate\Filesystem\Filesystem;
use Illuminate\Support\Str;

class CreateModuleCommand extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'make:module {name}';    
    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Créer un module avec la structure de dossiers et fichiers prédéfinie';


    protected $filesystem;

    public function __construct(Filesystem $filesystem)
    {
        parent::__construct();
        $this->filesystem = $filesystem;
    }


    /**
     * Execute the console command.
     */
    public function handle()
    {
        $name = $this->argument('name');
        $modulePath = base_path("modules/{$name}");

        $folder = strtolower($name);
        $namespace = "namespace modules\\$folder";

        // Définition de la structure du module et du contenu par défaut
        $structure = [
            "config" => [
                "sidebar.php" => "<?php\n\nreturn [\n    // Configuration du menu pour le module {$name}\n    '$folder' => [\n        'label' => '$name',\n        'name' => '$folder',\n        'icon' => '',\n        'active' => false,\n        'route' => '',\n        'child' => []\n    ]\n];"
            ],
            "Http/Controllers" => [
                "{$name}Controller.php" => "<?php\n\n$namespace\\Http\\Controllers;\n\nuse App\Http\Controllers\Controller;\n\nclass {$name}Controller extends Controller\n{\n    public function index()\n    {\n        return view('{$folder}::index');\n    }\n}"
            ],
            "Models" => [
                "{$name}.php" => "<?php\n\n$namespace\\Models;\n\nuse Illuminate\Database\Eloquent\Model;\n\nuse Illuminate\Database\Eloquent\Factories\HasFactory;\n\nclass {$name} extends Model\n{\n  use HasFactory;\n\n  protected \$fillable = [];\n}"
            ],
            "Providers" => [
                "{$name}ServiceProvider.php" => "<?php\n\n$namespace\\Providers;\n\nuse Illuminate\Support\ServiceProvider;\n\nclass {$name}ServiceProvider extends ServiceProvider\n{\n    public function boot()\n    {\n    \$this->loadMigrationsFrom(base_path('modules/{$folder}/database/migrations'));    \$this->loadRoutesFrom(base_path('modules/{$folder}/routes/web.php'));\n        \$this->loadViewsFrom(base_path('modules/{$folder}/resources/views'), '{$folder}');\n    }\n}"
            ],
            "database/migrations" => [
                "create_{$folder}_table.php" => "<?php\n\nuse Illuminate\Database\Migrations\Migration;\nuse Illuminate\Database\Schema\Blueprint;\nuse Illuminate\Support\Facades\Schema;\n\nclass Create" . ucfirst($folder) . "Table extends Migration\n{\n    public function up()\n    {\n        Schema::create('{$folder}', function (Blueprint \$table) {\n            \$table->id();\n            // Ajoutez ici les colonnes de votre table\n            \$table->timestamps();\n        });\n    }\n\n    public function down()\n    {\n        Schema::dropIfExists('{$folder}');\n    }\n}\n"
            ],
            "resources/js" => [
                "app.js" => "import PrimeVue from 'primevue/config';\nimport Aura from '@primevue/themes/aura';\nimport { ZiggyVue } from '../../../../vendor/tightenco/ziggy/dist';\nimport { createApp } from 'vue';\nimport List from './components/List.vue';\n\nconst app = createApp({});\n\napp.use(ZiggyVue)\n    .use(PrimeVue, {\n        theme: {\n            preset: Aura\n        }\n    });\n\napp.component('List', List);\n\napp.mount('#{$folder}');"
            ],
            "resources/js/components" => [
                "List.vue" => "<template>\n    <div>{$name}</div>\n</template>"
            ],
            "resources/views" => [
                "index.php" => "<h1>Bienvenue dans le module {$name}</h1>"
            ],
            "routes" => [
                "web.php" => "<?php\n\nuse Illuminate\Support\Facades\Route;\nuse modules\\{$folder}\\Http\\Controllers\\{$name}Controller;\n\nRoute::get('/{$name}', [{$name}Controller::class, 'index']);"
            ],
        ];

        // Création des dossiers et des fichiers avec le contenu par défaut
        foreach ($structure as $directory => $files) {
            $path = strtolower($modulePath)."/{$directory}";
            $this->filesystem->makeDirectory($path, 0755, true, true);

            foreach ($files as $file => $content) {
                $filePath = "{$path}/{$file}";
                $this->filesystem->put($filePath, $content);
                $this->info("Fichier créé : {$filePath}");
            }
        }

        // Exécution des commandes Artisan pour mettre à jour le cache
        try {
            $this->call('config:cache');
            $this->call('route:cache');
            $this->call('view:cache');

            // Exécuter la commande Composer dump-autoload
            exec('composer dump-autoload', $output, $returnVar);

            if ($returnVar !== 0) {
                throw new \Exception('Erreur lors de l\'exécution de composer dump-autoload: ' . implode("\n", $output));
            }

            $this->info("Cache et autoload mis à jour avec succès !");
            return 0; // Indiquer le succès
        } catch (\Exception $e) {
            $this->error("Erreur lors de la mise à jour du cache : " . $e->getMessage());
            return 1; // Indiquer l'échec
        }
    }
}
