<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class Products extends Model
{
    use HasFactory;
    
    protected $table = "products";
    protected $fillable = [
        'title',
        'reference',
        'numero',
        'barcode',
        'image',
        'status',
        'description',
        'unite_id',
        'unite',
        'username',
        'stock_management',
        'is_tva_inclusive',
        'purchase_price',
        'tva_rate',
        'price',
        'expiration_date',
        'reorder_level',
        'position',
        'background',
        'color',
        'slug',        
        'price_variant',
        'cost_price',        
    ];
    

    public function categories()
    {
        return $this->belongsToMany(Category::class, 'products_categories', 'product_id', 'category_id');
    }
    
    public function dataprice()
    {
        return $this->hasMany(ProductPrice::class, 'product_id');
    }

    public function category() {
        return $this->belongsToMany(Category::class, 'products_categories', 'product_id', 'category_id')
                    ->where('products_categories.pple', 1);
    }
    
    public function unitedetail(){
        return $this->belongsTo(Unite::class, 'unite_id');
    }

    public static function numero(String $code = "", Int $category_id)
    {
        $last = Products::join('products_categories', 'products_categories.product_id', '=', 'products.id')
                        ->where('category_id', $category_id)
                        ->where('pple', 1)
                        ->orderByDesc("products.created_at")
                        ->limit(1)
                        ->first();        

        $lastnum = !is_null($last) ? $last->numero : 0;
        $index = $lastnum + 1;
        $reference = auto_number("product", $index);

        if (strpos($reference, 'CATEGORY') !== false) {            
            $reference = str_replace('CATEGORY', $code, $reference);
        }

        return [
            "reference" => $reference,
            "numero" => $index
        ];
    }
}
