<?php

namespace modules\crm\Http\Controllers;

use App\Http\Controllers\Controller;
use App\Images;
use Exception;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\File;
use modules\crm\Models\BusinessContact;
use modules\crm\Models\BusinessContactDocument;
use modules\crm\Models\CustomerGroup;

class SettingController extends Controller{

    public function index(){
        return view("crm::setting");
    }

    public function groups(Request $request){
        $page = isset($request->pagesize) ? $request->pagesize : 25;
        $groups = CustomerGroup::orderBy('title')->paginate($page);
        $groups->transform(function($group){
            $group->b2b = (int)$group->b2b == 1;
            $group->credit = (int)$group->credit == 1;
            $group->is_default = (int)$group->is_default == 1;

            return $group;
        });
        return response()->json([
            'status' => 'success',
            'groups' => $groups
        ]);
    }

    public function groupSave(Request $request) {
        try {                        
            $request->validate([
                'title' => 'required'
            ]);

            $id = $request->id;

            $data = [
                "title" => $request->title,
                "rate_type" => $request->rate['type']['value'],
                "rate_value" => $request->rate['value'],
                "b2b" => $request->b2b,
                "credit" => $request->credit,                
                "updated_at" => date_now(),
            ];

            if((int)$id == 0){
                $data["created_at"] = date_now();
                CustomerGroup::create($data);
                $message = 'Enregistrement éffectuée avec succès';
            }else{
                CustomerGroup::where('id', $id)->update($data);
                $message = 'Mise à jour éffectuée avec succès';
            }
            
            return response()->json([
                'status' => 'success',
                'message' => $message
            ]);
            
        } catch (\Throwable $th) {
            throw $th;
        }
    }

    public function groupStatus(Request $request){
        try {
            $field = $request->field;

            if($field == 'is_default'){
                CustomerGroup::query()->update([
                    'is_default' => 0
                ]);
            }

            CustomerGroup::where('id', $request->id)->update([
                $field => $request->value,                
                "updated_at" => date_now()
            ]);

            return response()->json([
                'status' => 'success',
                'message' => 'Changement état éffectuée avec succès'
            ]);
        } catch (\Throwable $th) {
            throw $th;
        }
    }
    
    public function groupDestroy(string $type, int $id){
        try {            
            CustomerGroup::where('id', $id)->delete();
            return response()->json([
                'status' => 'success',
                'message' => 'Suppréssion éffectuée avec succès'
            ]);
        } catch (\Throwable $th) {
            throw $th;
        }
    }

    public function numerotation(Request $request){
        $type = $request->type;
        $numerotation = numerotation($type);
        return response()->json([
            'status' => 'succcess',
            'numerotation' => $numerotation
        ]);
    }

    public function numerotationSave(Request $request){
        try {
            $type = $request->type;
            
            DB::table('numerotation')->where("description", $type)->update([            
                'format' => $request->format,
                'begin_num' => $request->debut,
                'updated_at' => date_now(),
            ]);

            return response()->json([
                'status' => 'success',
                'message' => 'Mis à jour numérotation éffectué avec succès'
            ]);
        } catch (\Throwable $th) {
            throw $th;
        }
    }

    
}