<?php

namespace modules\catalogs\services;

use Barryvdh\DomPDF\Facade\Pdf;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Log;
use modules\catalogs\Models\HS;
use modules\catalogs\Models\ProductCategory;
use modules\catalogs\Models\ProductCustomerPrice;
use modules\catalogs\Models\Products;
use modules\catalogs\Models\ProductStock;
use modules\catalogs\Models\ProductSubLocation;
use modules\catalogs\Models\ProductSupplierPrice;
use modules\crm\Models\CustomerGroup;
use modules\location\Models\Location;
use modules\sales\Models\AccountingDocument;
use modules\stocks\Models\Inventory;

class ProductService
{    
    public static function numero(String $code = "", Int $category_id)
    {        
        $last = Products::whereNotNull("numero") #join('products_categories', 'products_categories.product_id', '=', 'products.id')
                        #->where('category_id', $category_id)
                        #->where('pple', 1)
                        ->orderByDesc("products.created_at")
                        ->limit(1)
                        ->first();
        #dd($last);

        $lastnum = !is_null($last) ? $last->numero : 0;
        $index = $lastnum + 1;
        $reference = auto_number("product", $index);

        if (strpos($reference, 'CATEGORY') !== false) {            
            $reference = str_replace('CATEGORY', $code, $reference);
        }

        return [
            "reference" => $reference,
            "numero" => $index
        ];
    } 

    public static function products(array $filters = [], int $pagination = 0)
    {        
        $relations = ['categories', 'locations', 'category', 'unitedetail', 'stock', 'dataprice', 'supplier_price', 'stock_hs'];
        if(isset($filters['with'])){
            if($filters['with'] == 'stock-story'){
                $relations[] = "stockStory";
            }
        }

        $query = Products::with($relations)
            ->join('products_locations', 'products_locations.product_id', '=', 'products.id')
            ->select(
                'products.*',
                'products_locations.status as location_status',
                'products_locations.reorder_level as location_reorder_level',
                'products_locations.description as location_description',
                'products_locations.position as location_position',
                'products_locations.price_variant as location_price_variant',
                'products_locations.is_tva_inclusive as location_is_tva_inclusive',
                'products_locations.tva_rate as location_tva_rate',
                'products_locations.cost_price as location_cost_price',
                'products_locations.cmup as location_cmup',
                'products_locations.frns_id as location_frns_id',
                'products_locations.frns as location_frns',
                'products_locations.frns_is_tva_inclusive as location_frns_is_tva_inclusive',
                'products_locations.frns_tva as location_frns_tva',
                'products_locations.frns_price as location_frns_price',
                'products_locations.purchase_price as location_purchase_price',
                'products_locations.delivery_status as delivery_status',
                'products_locations.delivery_price as delivery_price',
            )->distinct(); 
        
        
        $conditions = [];
        if (!empty($filters)) {                            
            self::applyFilters($query, $filters, $conditions);
        }        
        
        // Récupérer les produits avec pagination ou sans
        $query->orderBy('products.title');        
        $products = $pagination == 0 ? $query->get() : $query->paginate($pagination);        
        #$products = $query->get();        

        // Précharger les relations et données nécessaires
        $load = [
            'locations' => function ($query) use ($conditions) {                
                if (isset($conditions['products_locations.location_id'])) {
                    $query->where('location_id', $conditions['products_locations.location_id']);
                }
            },
            'categories',
            'unitedetail',
            'stock' => function ($query) use ($conditions) {
                if (isset($conditions['products_locations.location_id'])) {
                    $query->where('location_id', $conditions['products_locations.location_id']);
                }
            },
            'stock_hs' => function ($query) use ($conditions) {
                if (isset($conditions['products_locations.location_id'])) {
                    $query->where('location_id', $conditions['products_locations.location_id']);
                }
            },
            'dataprice' => function ($query) use ($conditions) {
                if (isset($conditions['products_locations.location_id'])) {
                    $query->where('location_id', $conditions['products_locations.location_id']);
                }
                if (isset($conditions['group_id'])) {                           
                    $query->where('group_id', $conditions['group_id']);
                }
            },
            'supplier_price' => function ($query) use ($conditions) {
                if (isset($conditions['products_locations.location_id'])) {
                    $query->where('products_suppliers_price.location_id', $conditions['products_locations.location_id']);                    
                }
                $query->orderByDesc('products_suppliers_price.created_at');                
            },
            
        ];

        if(isset($filters['with'])){
            if($filters['with'] == 'stock-story'){
                $load['stockStory'] = function ($query) use ($conditions) {
                    if (isset($conditions['products_locations.location_id'])) {
                        $query->where('location_id', $conditions['products_locations.location_id']);
                    }
                };
            }
        }

        $products->load($load);            
        
        // Ajouter des champs supplémentaires directement sans boucles coûteuses
        $products->transform(function ($product) use ($filters) {
            $price = $product->dataprice->first();            

            $product->emplacement = $product->locations->first();
            $product->stock = $product->stock; // Récupérer directement les valeurs stockées
            $product->stock_hs = $product->stock_hs;
            $product->price = $price ? $price->price : 0;            
            $product->supplier_prices = $product->supplier_price;

            if($product->stockStory){
                $product->stock_story = $product->stockStory;
            }

            if(isset($filters['with']) && $filters['with'] == 'inventories-details'){
                $slug = $filters['inventory-slug'];
                $inventory  = Inventory::with(['details'])->where('slug', $slug)->first();
                if ($inventory) {
                    // Filtrer les détails pour ne garder que ceux liés au produit en cours
                    $product->inventory = [
                        'id' => $inventory->id,
                        'reference' => $inventory->reference,
                        'slug' => $inventory->slug,
                        'details' => $inventory->details->where('product_id', $product->id)->values(),
                    ];
                }
            }

            return $product;
        });                
        
        return $products;
    }

    public static function getLowStockProducts($locationId)
    {
        return Products::select('products.*', DB::raw('COALESCE(products_stocks.stock, 0) as stock'))
            ->leftJoin('products_stocks', 'products.id', '=', 'products_stocks.product_id')
            ->where(function($query) {
                // Inclure les produits avec un stock inférieur au reorder_level
                $query->whereRaw('COALESCE(products_stocks.stock, 0) < products.reorder_level')
                      // Inclure également les produits avec un stock égal à 0
                      ->orWhereRaw('COALESCE(products_stocks.stock, 0) = 0');
            })
            ->where('products_stocks.location_id', $locationId) // Filtre par location
            ->get();
    }

    public static function getTopSoldProducts(int $location)
    {        
        $products = DB::table('accounting_documents_details as details')
                    ->where('location_id', $location)
                    ->where('row_type', 'product')
                    ->join('accounting_documents as docs', 'details.accounting_document_id', '=', 'docs.id')
                    ->where('docs.document_type', 'invoice') // Filtrer uniquement les factures
                    ->selectRaw('details.product_id, details.product, SUM(details.qty) as total_qty_sold')
                    ->groupBy('details.product_id', 'details.product') // Regrouper par produit
                    ->orderByDesc('total_qty_sold') // Trier par quantité vendue
                    ->limit(10) // Limiter à 10 produits
                    ->get();

        $products->transform(function($product){            
            $product->categories = ProductCategory::with(['category'])->where("product_id", $product->product_id)->get();

            return $product;
        });

        return $products;
    }

    public static function getMonthlySales($locations)
    {
        $currentYear = date_now()->year; // Année en cours
        $currentMonth = date_now()->month; // Mois en cours
        $months = range(1, $currentMonth); // Seulement les mois courant et passés                

        // Récupérer les ventes existantes
        $sales = AccountingDocument::where('document_type', 'invoice')
            ->where('validate', 1)
            ->whereYear('accounting_document_date', $currentYear)
            ->whereMonth('accounting_document_date', '<=', $currentMonth) // Seulement les mois passés et en cours
            ->selectRaw('MONTH(accounting_document_date) as month, location_id, location, COUNT(*) as sales_count')
            ->groupByRaw('MONTH(accounting_document_date), location_id, location')
            ->orderByRaw('MONTH(accounting_document_date), location_id')
            ->get()
            ->keyBy(fn($sale) => "{$sale->month}-{$sale->location_id}");

        // Construire la structure complète avec des valeurs par défaut (0 ventes)        
        $results = collect();
        foreach ($months as $month) {
            foreach ($locations as $location) {
                $key = "{$month}-{$location->id}";
                $results->push([
                    'year' => $currentYear,
                    'month' => $month,
                    'location_id' => $location->id,
                    'location' => $location->name, // Assure-toi que "name" correspond au bon champ
                    'total' => $sales[$key]->sales_count ?? 0,
                ]);
            }
        }

        return $results;
    }

    public static function getMonthlyCA($locations)
    {
        $currentYear = now()->year; // Année en cours
        $currentMonth = now()->month; // Mois en cours
        $months = range(1, $currentMonth); // Seulement les mois courants et passés                

        // Récupérer les ventes existantes avec la somme de total_ttc
        $sales = AccountingDocument::where('document_type', 'invoice')
            ->where('validate', 1)
            ->whereYear('accounting_document_date', $currentYear)
            ->whereMonth('accounting_document_date', '<=', $currentMonth) // Seulement les mois passés et en cours
            ->selectRaw('MONTH(accounting_document_date) as month, location_id, location, SUM(total_ttc) as total_sales')
            ->groupByRaw('MONTH(accounting_document_date), location_id, location')
            ->orderByRaw('MONTH(accounting_document_date), location_id')
            ->get()
            ->keyBy(fn($sale) => "{$sale->month}-{$sale->location_id}");

        // Construire la structure complète avec des valeurs par défaut (0 ventes)        
        $results = collect();
        foreach ($months as $month) {
            foreach ($locations as $location) {
                $key = "{$month}-{$location->id}";
                $results->push([
                    'year' => $currentYear,
                    'month' => $month,
                    'location_id' => $location->id,
                    'location' => $location->name, // Assure-toi que "name" correspond au bon champ
                    'total' => $sales[$key]->total_sales ?? 0,
                ]);
            }
        }

        return $results;
    }


    public static function getSalesCountByLocation()
    {
        // Récupération des ventes par emplacement
        $salesByLocation = Location::withCount(['invoices as total_sales' => function ($query) {            
            $query->whereYear('accounting_document_date', date_now()->format('Y'));
        }])
        ->get()
        ->map(function ($location) {
            // Retourner l'emplacement avec ses ventes, ou 0 s'il n'y a pas de ventes
            return [
                'location_id' => $location->id,
                'location' => $location->title,
                'total_sales' => $location->total_sales ?? 0,
            ];
        });
        
        return $salesByLocation;
    }

    public static function getSalesSumByLocation()
    {
        // Récupération du total des ventes (total_ttc) par emplacement
        $salesByLocation = Location::withSum(['invoices as total_sales' => function ($query) {            
            $query->whereYear('accounting_document_date', now()->year);
        }], 'total_ttc')
        ->get()
        ->map(function ($location) {
            // Retourner l'emplacement avec le total des ventes, ou 0 s'il n'y a pas de ventes
            return [
                'location_id' => $location->id,
                'location' => $location->title,
                'total_sales' => $location->total_sales ?? 0,
            ];
        });

        return $salesByLocation;
    }

    public static function hsMotif(){
        return HS::select('id', 'title')->get();
    }


    public function printdocument(array $products){
        $col = $products[0];
        $col = array_map(function ($item) {  
            return [
                'title' => $item,
                'align' => str_contains(strtolower($item), 'prix') || str_contains(strtolower($item), 'cmup') ? 'right' : (str_contains(strtolower($item), 'stock') ? 'center' : 'left'),
                'width' => str_contains(strtolower($item), 'prix') || str_contains(strtolower($item), 'cmup') ? '14%' : (str_contains(strtolower($item), 'stock') ? '8%' : 'auto'),
            ];
        }, $col);

        unset($products[0]);
        $data = array_values($products);

        // Vérification des données avant de générer le PDF
        $pdf = Pdf::loadView('documents.products.index', [
            'cols' => $col,
            'products' => $data,
        ]);

        $pdf->setOptions([
            'isHtml5ParserEnabled' => true,
            'isRemoteEnabled' => true,
            'isPhpEnabled' => true,
        ]);

        $path = public_path("pdf/products");
        $filePath = $path . '/products.pdf';

        if (!file_exists($path)) {
            File::makeDirectory($path, 0777, true, true);
        }

        $pdf->save("$path/products.pdf");
        if (!file_exists("$path/products.pdf")) {
            abort(500, "Le fichier PDF n'a pas été généré correctement.");
        }
                
        return [
            'url' => asset('pdf/products/products.pdf')
        ];
    }

    // Appliquer les filtres de recherche
    private static function applyFilters($query, array $filters, array &$conditions)
    {
        if (isset($filters['id'])) {
            $query->where('products.id', $filters['id']);
        }
        if (isset($filters['slug'])) {
            $query->where('slug', $filters['slug']);
        }        
        if (isset($filters['location'])) {
            $query->where('products_locations.location_id', $filters['location']);
            $conditions['products_locations.location_id'] = $filters['location'];
        }
        if(isset($filters['category']) && !is_null($filters['category'])){
            $query->join('products_categories', 'products_categories.product_id', '=', 'products.id');
            $query->where('products_categories.category_id', $filters['category']);
        }

        // Ajouter le filtre pour 'group_id' s'il est présent dans les filtres
        if (isset($filters['group_id'])) {
            $conditions['group_id'] = $filters['group_id'];
        }        

        if (isset($filters['keyword']) && isset($filters['criteria'])) {
            $query->where("products.{$filters['criteria']}", 'LIKE', "%{$filters['keyword']}%");
        }
    }

    // Récupérer l'emplacement du produit
    private static function getProductLocation($productId, $conditions)
    {
        return ProductSubLocation::select('products_sublocations.*', 'products_locations.location_id as site_id')
                    ->join('products_locations', 'products_locations.id', '=', 'products_sublocations.product_location_id')
                    ->where($conditions)
                    ->where('products_sublocations.product_id', $productId)
                    ->first();
    }

    // Récupérer le stock du produit
    private static function getProductStock($productId, $conditions)
    {
        $stockInfo = null;
        if(isset($conditions['products_locations.location_id'])){
            $stockInfo = ProductStock::where($conditions)
                        ->join('products_locations', 'products_locations.id', '=', 'products_stocks.location_id')
                        ->where('products_stocks.product_id', $productId)
                        ->first();
        }
        
        return !is_null($stockInfo) ? $stockInfo->stock : 0;
    }

    // Récupérer le prix client du produit
    private static function getCustomerPrice($productId, $conditions)
    {
        $prices = ProductCustomerPrice::where($conditions)
                    ->join('products_locations', 'products_locations.id', '=', 'products_customer_price.location_id')
                    ->where('products_customer_price.product_id', $productId)
                    ->first();
        return $prices->price ?? 0;
    }

    // Récupérer les détails du prix client
    private static function getCustomerPriceDetails($productId, $conditions)
    {
        return ProductCustomerPrice::where($conditions)
                    ->join('products_locations', 'products_locations.id', '=', 'products_customer_price.location_id')
                    ->where('products_customer_price.product_id', $productId)
                    ->get();
    }

    // Récupérer le prix fournisseur du produit
    private static function getSupplierPrices($productId, $conditions)
    {
        return ProductSupplierPrice::with('supplier')
                    ->where($conditions)
                    ->join('products_locations', 'products_locations.id', '=', 'products_suppliers_price.location_id')
                    ->where('products_suppliers_price.product_id', $productId)
                    ->get();
    }
}