<?php

namespace modules\location\Http\Controllers;

use App\Http\Controllers\Controller;
use App\Images;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Config;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Str;
use modules\catalogs\Models\Unite;
use modules\crm\Models\BusinessContact;
use modules\location\Models\Location;
use modules\location\Models\LocationNested;
use modules\sales\Models\AccountingDocument;
use modules\sales\Models\Invoice;
use modules\sales\Models\InvoicePayment;
use modules\sales\services\AccountingDocService;

class LocationController extends Controller
{
    public function index(Request $request)
    {       
        if($request->ajax()){
            $settings = settings();
            $datalocation = config('location.location');        
            
            return response()->json([
                'status' => 'sucdess',
                'settings' => $settings,
                'datalocation' => $datalocation,
            ]);
        }
        
        return view('location::index', [
            'page' => 'list'
        ]);
    }

    public function invoices($type, $site)
    {                            
        return view('location::index', [
            'page' => 'invoice'
        ]);
    }
    
    public function invoice_detail(String $type, String  $site, String  $slug, Request $request)
    {                   
        $doc = Invoice::where('slug', $slug)->first();
        if(is_null($doc)){
            return redirect()->route('app.sales.documents.edit', ['slug' => $slug, 'type' => 'invoice']);
        }
        
        if($request->ajax()){            
            $location = Location::where('slug', $site)->first();    
            $invoice = (new Invoice())->invoices([
                'slug' => $slug
            ])->first();

            return response()->json([
                'status' => 'success',
                'location' => $location,
                'invoice' => $invoice,
                'unites' => Unite::select('id', 'title', 'is_default')->get(),
            ]);
        }

        $page = 'detail';
        if($request->has('tab')){
            $page = $request->input('tab');
        }        

        return view('location::index', [
            'page' => $page,            
        ]);
    }    

    public function getinvoice($type, $site)
    {                    
        $page = isset($request->pagesize) ? $request->pagesize : 25;

        $location = Location::where('slug', $site)->first();        
        $query = Invoice::with('payments')->where('location_id', $location->id);

        $total = [];
        $data = $query->get();
        $total['ht'] = $data->sum('total_ht');
        $total['ttc'] = $data->sum('total_ttc');
        $total['paid'] = $data->sum('payments.amount');
        $total['rap'] = $total['ttc'] - $total['paid'];

        $invoices  = $query->paginate($page);
        #dd($invoices);
        
        $invoices->transform(function($item){            
            $payments = $item->payments;
            $payment = $payments->sum('amount');

            $item->payments = $payments;
            $item->payment_total = $payment;
            
            $rap = (float)$payment - (float)$item->total_ttc;
            $item->rap = $rap;
            return $item;
        });
        
        $location = Location::where('slug', $site)->first();    
        $response = [
            'status' => 'success',
            'invoices' => $invoices,
            'total' => $total,
            'location' => $location
        ];                    
        return response()->json($response);
    }

    public function invoicePayment(Request $request) {
        try {
            $request->validate([
                'amount' => 'required|numeric|not_in:0',                
                'paid_date' => 'required|date',
                'method.id' => 'required'
            ]);
            DB::beginTransaction();            

            $invoice_id = $request->invoice_id;
            $invoice = Invoice::find($invoice_id);            

            $user = Auth::user();
            InvoicePayment::create([
                "invoice_id" => $invoice_id,
                "reference" => $invoice->reference,
                "user_id" => $user->id,
                "username" => $user->name,                
                "payment_method_id" => $request->method['id'],
                "payment_method" => $request->method['title'],
                "amount" => $request->amount,
                "observation" => $request->observation,
                'created_at' => date_now(),
                'updated_at' => date_now(),
            ]);

            DB::commit();

            $invoice = (new Invoice())->invoices([
                'id' => $invoice_id
            ])[0];

            return response()->json([
                'status' => 'success',
                'invoice' => $invoice,
                'message' => 'save paid successfully',
            ]);
            
        } catch (\Throwable $th) {
            DB::rollBack();
            throw $th;
        }
    }

    public function locations(Request $request){
        try {
            $page = isset($request->pagesize) ? $request->pagesize : 25;
            $query = Location::with('invoices.payments');

            $location = Config::get('location.location', []);                
            $type = 'site';
            if($request->type){
                $type = $request->type;
                $query->where('type', $request->type);
            }

            $slug = $request->input($location[$type]['parent']);
            $parent = Location::with('parent', 'child')->where('slug', $slug)->first();
            if(!is_null($parent)){
                $query->where('parent_id', $parent->id);
            }
            
            if((int)$page == 0){
                $locations = $query->get();
            }else{
                $locations = $query->paginate($page);
            }

            #dd($locations);
            
            $locations->transform(function ($location) {
                $location->stock = (int)$location->stock_management == 1;
                $location->delivery = (int)$location->has_delivery == 1;
                $location->parent = (int)$location->is_parent == 1;
            
                $location->paid = 0;
                $location->rap = 0;
                $location->pricetotal = 0;

            
                foreach ($location->invoices as $invoice) {
                    $invoice->paid = $invoice->payments->sum('amount');
                    $invoice->rap = $invoice->total_ttc - $invoice->paid;
            
                    $location->pricetotal += $invoice->total_ttc;
                    $location->paid += $invoice->paid;
                    $location->rap += $invoice->rap;
                }
            
                return $location;
            });

            #dd($locations->toArray());
            
            $response = [
                'status' => 'success',
                'locations' => $locations
            ];                    
            #dd($location[$type]['parent'], $request->site);

            $response['parent'] = $parent;

            return response()->json($response);
        } catch (\Throwable $th) {            
            throw $th;
        }
    }

    public function save(Request $request)
    {
        #dd($request->all());
        $id = $request->id;
        $data = [
            'header' => $request->header,
            'footer' => $request->footer,
        ];
        Location::where('id', $id)->update($data);

        if ($request->hasFile('file') && $request->file('file')->isValid()) {
            $image = $request->file('file');   
            
            $imageData = (new Images('images/sites/logo'))->image_upload($image, [
                'width' => 220,
                'height' => 240,
            ]);
            #dd($imageData['filename'], $id);
            Location::where('id', $id)->update([
                'logo' => $imageData['filename']
            ]);                        
        }
        
        return response()->json([
            'status' => 'success',
            'message' => "Paramètre document mis à jour avec succès"
        ]);
        
    }

    public function destroy($id) {
        $location = Location::find($id);
        $location->delete();
        return response()->json([
            'status' => 'success',
            'message' => 'Site supprimé avec succès'
        ]);
    }
}