<?php

namespace modules\sales\Http\Controllers;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Session;
use Maatwebsite\Excel\Facades\Excel;
use modules\sales\Exports\DocumentExport;
use modules\catalogs\Models\Container;
use modules\catalogs\Models\Products;
use modules\catalogs\Models\Unite;
use modules\catalogs\services\ProductService;
use modules\crm\Models\BusinessContact;
use modules\crm\Models\BusinessContactTransaction;
use modules\crm\services\CrmService;
use modules\location\Models\Location;
use modules\sales\Models\AccountingDocSetting;
use modules\sales\Models\AccountingDocStatusLog;
use modules\sales\Models\AccountingDocument;
use modules\sales\Models\AccountingDocumentDetail;
use modules\sales\Models\AccountingDocumentLog;
use modules\sales\Models\AccountingDocumentPayment;
use modules\sales\Models\AccountingDocumentStatus;
use modules\sales\Models\Caisse;
use modules\sales\Models\CaisseStatus;
use modules\sales\Models\Invoice;
use modules\sales\Models\InvoiceType;
use modules\sales\Models\Taxe;
use modules\sales\services\AccountingDocService;
use modules\sales\services\BasketService;
use modules\sales\services\CaisseService;
use modules\sales\services\CreditService;

class AccountingDocumentController extends Controller
{    
    /**
     * Display a listing of the resource.
     */
    public function index(Request $request)
    {        
        if($request->ajax()){
            $type = $request->type;
            $category = $request->category;
            AccountingDocument::where('validate', 0)
                                ->where('category', $category)
                                ->where('document_type', $type)
                                ->delete();

            $filter = [];
            if($request->has('location')){
                $filter['location'] = $request->location;
            }

            $status = (new AccountingDocService())->all_status($category, $type, $filter);


            $param = [];
            if(isset($request->status)){
                $p = explode('@', $request->status);
                $param['status'] = $p[0];
            }            

            $p = Auth::user()->getAllPermissions();
            
            $_status = AccountingDocumentStatus::where('type', $type)->get();              
            $permission_destroy = $p->contains('name', "sales.{$type}.destroy");
            if (!$permission_destroy) {                
                $_status = $_status->reject(fn($item) => $item->cancelled == 1);                
            }

            $permissions = array_values($p->filter(function ($permission) {
                return str_contains($permission->name, request()->type);
            })->toArray());

            if(is_null(Auth::user()->location_id)){
                $locations = Location::where('status', 'active')->get();
            }else{
                $locations = Location::where('id', Auth::user()->location_id)->get();
            }

            $status['data'] = $_status;
            return response()->json([
                'response' => 'success',
                'status' => $status,
                'param' => $param,
                'settings' => settings(),
                'permissions' => $permissions,
                'locations' => $locations,
                'auth' => Auth::user()
            ]);
        }

        return view('sales::documents.index');
    }   
    
    public function create(string $category, string $type)
    {
        try {
            DB::beginTransaction();            
            
            $date_release = date_now()->addDays(settings()['document_release_date']->value);
            
            $customer = BusinessContact::where('is_default', 1)->where('category', $category)->first();            
            $name = is_null($customer->company) ? $customer->lastname : $customer->company;

            $user = Auth::user();

            $location = my_location();
            $document = AccountingDocument::create([ 
                'category' => $category,
                'location_id' => $location->id,
                'location' => $location->title,
                "document_type" => $type,
                "customer_id" => $customer->id,
                "customer" => $name,
                "user_id" => $user->id,
                "username" => $user->name,        
                "edited_by"  => $user->id,
                "edited_name" => $user->name,
                "accounting_document_date" => date_now()->format('Y-m-d'),
                "accounting_document_release_date" => $date_release->format('Y-m-d'),
                "created_at" => date_now(),
                "updated_at" => date_now()
            ]);                              

            $document_id = $document->id; 
            $slug = $document_id ."-".generateString(16);
            $document->slug = $slug;
            $document->save();
    
            $status = AccountingDocumentStatus::where('type', $type)->where('use_default', 1)->first();            

            $document_status = AccountingDocStatusLog::create([
                'accounting_document_id' => $document_id,
                "reference" => $document->reference,
                'accounting_document_status_id' => $status->id,
                'accounting_document_status' => $status->title,
                'background' => $status->background,
                'color' => $status->color,
                'icon' => $status->icon,
                'user_id' => $user->id,
                "username" => $user->name,
                "created_at" => date_now(),
                "updated_at" => date_now(),
            ]);

            #dd($document_status);

            $doc = AccountingDocService::documenttype()[$type];
            AccountingDocumentLog::create([
                "accounting_document_id" => $document_id,
                "reference" => $document->reference,
                "accounting_document_status_id" => $status->id,
                "accounting_document_status" => $status->title,
                "title" => "Création $doc",
                "user_id" => $user->id,
                "username" => $user->name,
                "created_at" => date_now(),
                "updated_at" => date_now(),
            ]);
            
            DB::commit();            

            return redirect()->route('app.sales.documents.edit', ['slug' => $slug, 'type' => $type, 'category' => $category]);
        } catch (\Throwable $th) {
            DB::rollBack();
            throw $th;
        }
    }
    
    public function edit(string $category, String $type, String $slug, Request $request)
    {
        if($type == 'receipt'){
            return view('sales::receipt.detail');
        }

        $document = AccountingDocument::with('status')->where('slug', $slug)->first();
        #dd($document->toArray(), $slug);
        if(is_null($document)){
            abort(404);
        }

        $current_status = $document->status[0]->accounting_document_status_id;
        $status = [];

        $status = (new AccountingDocService())->statusUsed($type, $current_status);
        $xstatus = AccountingDocumentStatus::where('type', $type)
                    ->select('id', 'title', 'background', 'color', 'icon', 'description')
                    ->whereNotIn('id', $status)->get();        
        $_status = array_values($xstatus->toArray());  
        $customers = CrmService::customers();        

        $locations = Location::where('type', 'site')->select(
                        'id',
                        'type',
                        'title',
                        'is_parent',
                        'has_delivery',
                        'stock_management',
                    )->get();
        $location = my_location();
        $unites = Unite::select('id', 'title', 'is_default')->get();
        $taxes = Taxe::select('id', 'title', 'rate', 'is_default')->get();

        if(isset($request->tab)){
            $tab = $request->tab;

            if($tab == 'historiques'){
                if($request->ajax()){
                    return response()->json([
                        'settings' => settings(),
                        'document' => $document,                                  
                        'status' => $_status,
                        'customers' => $customers,
                        'locations' => [
                            'sites' => $locations,
                            'selected' => $location,
                            'edit' => Auth::user()->location_id == null
                        ]
                    ]);
                }

                return view('sales::documents.story');
            }elseif($tab == 'paiements'){
                
                if($request->ajax()){
                    $settings = AccountingDocSetting::all()->keyBy('name');
                    return response()->json([
                        'document' => $document,
                        'documentsettings' => $settings,
                        'settings' => settings(),
                        'status' => $_status,
                        'locations' => [
                            'sites' => $locations,
                            'selected' => $location,
                            'edit' => Auth::user()->location_id == null
                        ]
                    ]);
                }   
                return view('sales::documents.payment');
            }elseif($tab == 'emails'){   
                return view('sales::documents.email', [
                    'document' => $document,                    
                    'status' => $_status,
                    'customers' => $customers
                ]);
            }elseif($tab == 'footer'){
                $settings = AccountingDocSetting::all()->keyBy('name');                
                return view('sales::documents.InvoiceFooter', [
                    'document' => $document,
                    'document_settings' => $settings,
                    'status' => $_status,
                    'customers' => $customers,
                ]);
            }
        }

        if($request->ajax()){            
            return response()->json([
                'settings' => settings(),
                'document' => $document,            
                'unites' => $unites,
                'taxes' => $taxes,
                'status' => $_status,
                'customers' => $customers,
                'locations' => [
                    'sites' => $locations,
                    'selected' => $location,
                    'edit' => Auth::user()->location_id == null
                ]
            ]);
        }
        
        $title = AccountingDocService::documenttype()[$document->document_type];        
        return view('sales::documents.detail', [
            'title' => $title
        ]);
    }

    public function getdata(Request $request) {
        $type = $request->type;
        $category = $request->category;
        $page = isset($request->pagesize) ? $request->pagesize : 25;
        
        $data = ['validate' => 1];
        
        if($request->has('slug')){
            $data['slug'] = $request->input('slug');
            unset($data['validate']);
            $page = 0;
        }

        if($request->has('document_for')){
            $data['document_for'] = $request->input('document_for');
        }

        if(isset($request->status)){   
            $status = explode("@", $request->status);            
            if((int)$status[0] != 0){
                $data['status'] = $status[0];
            }
        }

        if(isset($request->criteria)){
            $criteria = $request->criteria;
            if($criteria == 'numero'){
                $data['reference'] = $request->keyword;
            }else{
                $data[$criteria] = $request->keyword;
            }        
        }                
        
        $documents = (new AccountingDocService())->documents($category, $type, $data, $page);        
        return response()->json([
            'status' => 'success',
            'documents' => $documents->toArray()
        ]);
    }

    public function store_info(Request $request){
        try {
            #dd($request->details);
            #dd($request->all());

            $validator = [
                'customer.id' => 'required',                
                'details' => 'required|array|min:1'
            ];
            $request->validate($validator);

            DB::beginTransaction();
            $type = $request->type;
            $category = $request->category;
            
            $location_id = $request->location['id'];
            $location = Location::find($location_id);

            $customer_id = $request->customer['id'];
            $customer = CrmService::customers()->where('id', $customer_id)->first();
            $address = $request->address;

            $document_id = $request->id;
            $date_document = $request->accounting_document_date;
            $date_release = $request->accounting_document_release_date;
            $linkto = $request->linked_to;

            $with_delivery = $request->delivery['active'];
            
            $user = Auth::user();

            $document = AccountingDocument::find($document_id);            
            
            $slug = $document->slug;
            $document->update([
                "location_id" => $location_id,
                "location" => $location->title,

                "link_to" => $linkto['value'],

                "accounting_document_id" => $linkto['value'] == 'none' ? null : '',
                "numero" => $linkto['value'] == 'none' ? null : '',
                "reference" => $linkto['value'] == 'none' ? null : '',
                "accounting_document_date" => $date_document,
                "accounting_document_release_date" => $date_release,

                "customer_id" => $customer_id,
                "customer" => $customer['title'],
                "customer_email" => $customer['email'],
                "customer_phone" => $customer['phone'],
                "customer_address" => $address,

                "document_for" => isset($request->invoice_type) && $request->invoice_type == 1 ? 'site' : 'customer',

                'document_logo' => $location->logo,
                'document_header' => $location->header,
                'document_footer' => $location->footer,

                'delivery' => $with_delivery ? 'active' : 'inactive'
            ]);

            $details = $request->details;
            AccountingDocumentDetail::where('accounting_document_id', $document_id)->delete();
            foreach ($details as $key => $item) {
                $product_id = null;
                $designation = $item['col']['designation']['value'];                

                $product_image = null;
                if($item['type'] == 'product' || $item['type'] == 'container'){
                    $designation = $item['col']['designation']['value']['title'];
                    $product_id = $item['col']['designation']['value']['id'];

                    if($item['type'] == 'product'){
                        $product = Products::find($product_id);
                        $product_image = $product->image;
                    }
                }
                if($item['type'] == 'saut-page') {
                    $designation = 'saut-page';
                }
                if($item['type'] == 'title' || $item['type'] == 'texte') {
                    $designation = $item['col']['text'];
                }                
                
                if(!is_null($designation)){
                    $qty = $item['col']['qte']['value'];                
                    $unite = $item['col']['unite']['value'];
                    #dd($unite);

                    $price = [];
                    if(isset($item['col']['prix'])){
                        $price = $item['col']['prix'];
                    }

                    #dd($price);

                    if($item['type'] == 'sous-total'){
                        $htprice = $item['col']['sousTotal'];
                    }else{
                        $htprice = !empty($price) ? $price['ht']['price'] : 0;
                    }                    

                    AccountingDocumentDetail::create([
                        'accounting_document_id' => $document_id,
                        'row_type' => $item['type'],
                        'product_id' => $product_id,
                        'product' => $designation,
                        'product_image' => $product_image,
                        'qty' => $qty,
                        'unite_id' => is_array($unite) ? $unite['id'] : 0,
                        'unite' => is_array($unite) ? $unite['title'] : 0,
                        'price_ht' => $htprice,
                        'discount_by' => !empty($price) ? ($price['remise']['by'] == '%' ? 'percent' : 'amount')  : 'percent',
                        'discount_rate' => !empty($price) ? $price['remise']['rate'] : 0,
                        'discount_price' => !empty($price) ? $price['remise']['price'] : 0,
                        'tva_rate' => !empty($price) ? $price['tva']['rate'] : 0,
                        'tva_price' => !empty($price) ? $price['tva']['price'] : 0,
                        'delivery_price' => $with_delivery ? (!empty($price) ? (float)$price['delivery'] / (float)$qty : 0) : 0,
                        'price_ttc' => !empty($price) ? $price['ttc'] : 0,
                        'created_at' => date_now(),
                        'updated_at' => date_now(),
                    ]);
                }
            }
            
            AccountingDocument::where('id', $document_id)->update([
                "validate" => 1,

                "edited_by" => $user->id,
                "edited_name" => $user->name,                

                "discount_by" => null,
                "discount_rate" => 0,
                "discount_price" => $request->total['remise'],

                "tva_rate" => 0,
                "tva_price" => $request->total['tva'],
                "total_ht" => $request->total['ht'],
                "total_ttc" => $request->total['ttc'],
                                
                "delivery_price" => $with_delivery ? $request->total['delivery'] : 0,

                "updated_at" => date_now()
            ]);

            $status = $document->status[0];
            $existStatusLog = AccountingDocStatusLog::where([
                'accounting_document_id' => $document_id,
                'accounting_document_status_id' => $status->accounting_document_status_id,
            ])->first();

            if(!is_null($existStatusLog)){
                AccountingDocStatusLog::create([
                    'accounting_document_id' => $document_id,
                    "reference" => $document->reference,
                    'accounting_document_status_id' => $status->accounting_document_status_id,
                    'accounting_document_status' => $status->accounting_document_status,
                    'background' => $status->background,
                    'color' => $status->color,
                    'icon' => $status->icon,
                    'user_id' => $user->id,
                    "username" => $user->name,
                    "created_at" => date_now(),
                    "updated_at" => date_now(),
                ]); 
            }
                    
            AccountingDocumentLog::create([
                "accounting_document_id" => $document_id,
                "reference" => $document->reference,
                "accounting_document_status_id" => $status->accounting_document_status_id,
                "accounting_document_status" => $status->accounting_document_status,
                "title" => "Modification ". AccountingDocService::documenttype()[$type],
                "user_id" => $user->id,
                "username" => $user->name,
                "created_at" => date_now(),
                "updated_at" => date_now(),
            ]);            

            DB::commit();

            $document = (new AccountingDocService())->documents($category, $type, ['slug' => $slug])->first();
            return response()->json([
                'status' => 'success',
                'message' => 'document saved successfully',
                'document' => $document
            ]);
        } catch (\Throwable $th) {
            DB::rollBack();
            throw $th;
        }
    }

    public function status(Request $request)
    {
        try {
            DB::beginTransaction();

            $document = AccountingDocument::findOrFail($request->id);
            $status = $request->status;
            $reference = $document->reference;            
            
            $location = $this->getLocation($document);
            
            if($document->category == "customer"){
                if ($this->isInvoiceWithLowStock($document, $location)) {
                    return $this->lowStockResponse($document);
                }

                if ($this->shouldAssignNumber($document, $status)) {
                    $numero = $this->assignDocumentNumber($document);
                    $reference = $numero['reference'];
                    
                    if ($document->document_type != 'quote') {
                        $this->handleBusinessTransaction($document, $status);
                    }
    
                    if ($document->document_type == 'invoice') {
                        (new AccountingDocService())->duplicateParentInvoice($document->id, 'decrease');
                    }
                }
                
                if ($document->document_type == 'credit' && (int)$status['pay'] == 1) {
                    (new CreditService())->handleCreditDocument($document, $status, $reference);
                }
            }else{
                if($document->document_type == 'invoice'){
                    $this->handleBusinessTransaction($document, $status);
                }
            }

            $this->logStatusChange($document, $status, $reference);

            DB::commit();

            return $this->successResponse($document);
        } catch (\Exception $e) {
            DB::rollBack();
            throw $e;
        }
    }

    private function getLocation($document)
    {
        return $document->document_for == 'site' 
            ? Location::where('id', $document->customer_id)->first() 
            : Location::where('id', $document->location_id)->first();
    }

    private function isInvoiceWithLowStock($document, $location)
    {
        if ($document->document_type != 'invoice' || (int)$location->is_parent == 1) {
            return false;
        }
        
        $parent = Location::where('is_parent', 1)->first();
        $details = AccountingDocumentDetail::where('accounting_document_id', $document->id)->get();
        
        foreach ($details as $detail) {
            if ($detail->row_type == 'product') {
                $stock = Products::where('id', $detail->product_id)->with('stock')->first()->stock
                    ->where('location_id', $parent->id)->first();
                
                if ((float)$stock->stock < (float)$detail->qty) {
                    return true;
                }
            }
        }
        
        return false;
    }

    private function lowStockResponse($document)
    {
        return response()->json([
            'status' => 'error',
            'info' => 'low-stock',
            'data' => [] // Mettre ici les détails du stock bas si nécessaire
        ], 422);
    }

    private function shouldAssignNumber($document, $status)
    {
        return is_null($document->numero) && (int)$status['use_default'] != 1 && (int)$status['cancelled'] != 1;
    }

    private function assignDocumentNumber($document)
    {
        $numero = (new AccountingDocService())->numero($document->document_type);
        $document->update([
            'reference' => $numero['reference'],
            'numero' => $numero['index'],
        ]);
        return $numero;
    }

    private function handleBusinessTransaction($document, $status)
    {
        #dd('business transaction');
        $transaction_type = (int)$status['pay'] == 1 ? "in" : "out";
        $exist_transaction = BusinessContactTransaction::where([
            'business_contact_type' => $document->category,
            'transaction_type' => $transaction_type,
            'document_type' => $document->document_type,
            'document_id' => $document->id,
        ])->first();        

        if (is_null($exist_transaction)) {
            $this->createBusinessTransaction($document, $transaction_type);
        }
    }

    private function successResponse($document)
    {
        $documents = (new AccountingDocService())->documents($document->category, $document->document_type, ['slug' => $document->slug]);
        return response()->json([
            'status' => 'success',
            'message' => 'Status updated successfully',
            'documents' => $documents,
        ]);
    }    

    private function createBusinessTransaction($document, $type)
    {
        $reference = $document->reference;
        $desc = "";
        if($document->document_type == 'invoice'){
            $desc = "Facture de vente #{$reference}, montant de {$document->total_ttc}";
        }

        if($document->document_type == 'credit'){
            $desc = "Facture d'avoir #{$reference}, montant de {$document->total_ttc}";
        }

        BusinessContactTransaction::create([
            'business_contact_id' => $document->customer_id,
            'business_contact_name' => $document->customer,
            'business_contact_type' => 'customer',
            'transaction_type' => $type,
            'document_type' => $document->document_type,
            'document_id' => $document->id,
            'document_reference' => $reference,
            'document_amount' => $document->total_ttc,
            'description' => $desc,
            'amount' => $document->total_ttc,
            'created_at' => now(),
            'updated_at' => now(),
        ]);
    }

    private function logStatusChange($document, $status, $reference)
    {
        $user = Auth::user();

        AccountingDocStatusLog::create([
            'accounting_document_id' => $document->id,
            'reference' => $reference,
            'accounting_document_status_id' => $status['id'],
            'accounting_document_status' => $status['title'],
            'background' => $status['background'],
            'color' => $status['color'],
            'icon' => $status['icon'],
            'user_id' => $user->id,
            'username' => $user->name,
            'created_at' => now(),
            'updated_at' => now(),
        ]);

        $docType = AccountingDocService::documenttype()[$document->document_type];
        AccountingDocumentLog::create([
            'accounting_document_id' => $document->id,
            'reference' => $reference,
            'accounting_document_status_id' => $status['id'],
            'accounting_document_status' => $status['title'],
            'title' => "Mise à jour status $docType",
            'user_id' => $user->id,
            'username' => $user->name,
            'created_at' => now(),
            'updated_at' => now(),
        ]);
    }


    /*public function status(Request $request)
    {
        #dd($request->all());

        try {            
            DB::beginTransaction();
            
            $document_id = $request->id;
            $document = AccountingDocument::find($document_id);
            $slug = $document->slug;
            
            $status = $request->status; 
            $reference = $document->reference;  
            
            #dd($status);
            if((int)$status['use_default'] != 1 || (int)$status['cancelled'] != 1){
                if(is_null($document->numero)){
                    $numero = (new AccountingDocService())->numero($document->document_type);                      
                    #dd($numero);
                    $reference = $numero['reference'];
                    AccountingDocument::where('id', $document_id)->update([
                        "reference" => $reference,
                        "numero" => $numero['index'],
                    ]);

                    if($document->document_type == 'invoice'){
                        (new AccountingDocService())->duplicateParentInvoice($document_id, 'decrease');
                    }                    
                }

                if($document->document_type == 'credit'){
                    if($document->document_for == 'customer'){
                        $amount = $document->total_ttc;
                        $desc = 'Facture avoir #'.$reference.', montant de '. $amount;

                        BusinessContactTransaction::create([
                            'business_contact_id' => $document->customer_id,
                            'business_contact_name' => $document->customer,
                            'business_contact_type' => 'customer',
                            'transaction_type' => 'out',
                            'document_type' => $document->document_type,
                            'document_reference' => $reference,
                            'document_amount' => $amount,
                            'description' => $desc,
                            'amount' => $amount,
                            'created_at' => date_now(),
                            'updated_at' => date_now()
                        ]);
                    }

                    if(!is_null($document->accounting_document_id) && (int)$status['pay'] == 1){
                        (new AccountingDocService())->docHasStockExitAndPayment($document_id);
                    }
                }                
            }

            AccountingDocStatusLog::create([
                'accounting_document_id' => $document_id,
                'reference' => $reference,
                'accounting_document_status_id' => $status['id'],
                'accounting_document_status' => $status['title'],
                'background' => $status['background'],
                'color' => $status['color'],
                'icon' => $status['icon'],                
                "user_id" => Auth::user()->id,
                "username" => Auth::user()->name,
                "created_at" => date_now(),
                "updated_at" => date_now(),
            ]);            

            $doc = AccountingDocService::documenttype()[$document->document_type];
            AccountingDocumentLog::create([
                "accounting_document_id" => $document_id,
                "reference" => $reference,
                "accounting_document_status_id" => $status['id'],
                "accounting_document_status" => $status['title'],
                "title" => "Mise à jour status $doc",
                "user_id" => Auth::user()->id,
                "username" => Auth::user()->name,
                "created_at" => date_now(),
                "updated_at" => date_now(),
            ]);

            DB::commit();

            $document = (new AccountingDocService())->documents($document->document_type, ['slug' => $slug]);
            return response()->json([
                'status' => 'success',
                'message' => 'status updated successfully',
                'documents' => $document
            ]);
        } catch (\Exception $th) {
            DB::rollBack();
            throw $th;
        }
    }*/

    public function payment(Request $request){
        try {
            #dd($request->all());

            DB::beginTransaction();
            $user = Auth::user();
            $type = $request->type;            
            $request->validate([
                'amount' => 'required|numeric|not_in:0',                
                'paid_date' => 'required|date',
                'method.id' => 'required'
            ]);

            $payment = $request->method;
            $document_id = $request->document_id;
            $document = (new AccountingDocService)->documents($type, ['id' => $document_id])[0];
            #dd($document);
            AccountingDocumentPayment::create([
                "accounting_document_id" => $document_id,
                "reference" => $document->reference,
                "user_id" => $user->id,
                "username" => $user->name,
                "payment_method_id" => $payment['id'],
                "payment_method" => $payment['title'],
                "payment_additionnal" => json_encode($request->additionnals),
                "amount" => $request->amount,
                "observation" => $request->observation,
                'created_at' => date_now(),
                'updated_at' => date_now(),
            ]);            

            $currentStatus = $document->status[0];
            $status = AccountingDocumentStatus::find($currentStatus->accounting_document_status_id);            

            $reference = $document->reference;
            $amount = $request->amount;
            if(is_null($reference)){
                $numero = (new AccountingDocService())->numero('invoice');

                $reference = $numero['reference'];
                AccountingDocument::where('id', $document_id)->update([
                    'numero' => $numero['index'],
                    'reference' => $reference,
                ]);
            }

            if($document->document_for == 'customer'){
                $desc = "";
                if($type == "invoice"){
                    $desc = 'Facture vente #'.$reference.': Paiement de '. $amount;
                }

                $payment_method = [
                    'id' => $payment['id'],
                    'title' => $payment['title'],
                    'additionnal' => $request->additionnals
                ];
                BusinessContactTransaction::create([
                    'business_contact_id' => $document->customer_id,
                    'business_contact_name' => $document->customer,
                    'document_id' => $document->id,
                    'business_contact_type' => 'customer',
                    'transaction_type' => 'in',
                    'document_type' => $type,
                    'document_reference' => $reference,
                    'document_amount' => $amount,
                    'description' => $desc,
                    'amount' => $amount,
                    'payment_method' => json_encode($payment_method),
                    'created_at' => date_now(),
                    'updated_at' => date_now()
                ]);
            }

            $reste = (double)$request->rap - (double)$request->amount;
            if($reste == 0){
                $status = AccountingDocumentStatus::where('type', $type)->where('pay', 1)->first();
                AccountingDocStatusLog::create([
                    'accounting_document_id' => $document_id,
                    "reference" => $reference,
                    'accounting_document_status_id' => $status->id,
                    'accounting_document_status' => $status->title,
                    'background' => $status->background,
                    'color' => $status->color,
                    'icon' => $status->icon,
                    'user_id' => $user->id,
                    "username" => $user->name,
                    "created_at" => date_now(),
                    "updated_at" => date_now(),
                ]);              
            }

            $doc = AccountingDocService::documenttype()[$document->document_type];
            AccountingDocumentLog::create([
                "accounting_document_id" => $document_id,
                "reference" => $reference,
                "accounting_document_status_id" => $status['id'],
                "accounting_document_status" => $status['title'],
                "title" => "Paiement $doc",
                "user_id" => Auth::user()->id,
                "username" => Auth::user()->name,
                "created_at" => date_now(),
                "updated_at" => date_now(),
            ]);

            DB::commit();

            $document = (new AccountingDocService())->documents($type, ['id' => $document_id])->first();
            return response()->json([
                'status' => 'success',
                'message' => 'save paid successfully',
                'document' => $document
            ]);

        } catch (\Exception $th) {
            DB::rollBack();
            throw $th;
        }
    }

    public function document($type, $slug)
    {                     
        $doc = (new AccountingDocService())->printdocument($type, $slug);
        return $doc['pdf']->setWarnings(false)->stream($doc['name'].'.pdf', array("Attachment" => false));
    }

    public function printOrExport(Request $request){
        #dd($request->all());
        $filters['document_type'] = $request->document;
        $filters['document_for'] = $request->document_for['value'];
        
        if($request->has('location') && $request->location['value'] != 0){
            $location = Location::where('slug', $request->location['value'])->first();
            $filters['location'] = $location->id;
        }
        if($request->has('customer') && !is_null($request->customer)){
            $filters['customer'] = $request->customer;
        }
        if($request->has('date') && !is_null($request->date)){
            $filters['date'] = $request->date;
        }
        if($request->has('status') && isset($request->status['id'])){
            $filters['status'] = $request->status['id'];
        }
        #dd($filters);
        
        $documents = [['Ref', 'Date', $filters['document_for'] == 'site' ? 'Site' : 'Client', 'Total HT', 'Remise', 'TVA', 'Total TTC', 'Status']];
        $query = AccountingDocument::with(['latestStatus', 'details'])
                    ->when(!empty($filters), function ($q) use ($filters) {
                        $q->where('document_type', $filters['document_type']);

                        if($filters['document_for'] != 'all'){
                            $q->where('document_for', $filters['document_for']);
                        }

                        // Filter by location if provided
                        if (!empty($filters['location'])) {
                            $q->where('location_id', $filters['location']);
                        }

                        // Filter by category if provided
                        if (!empty($filters['date'])) {
                            $q->where('accounting_document_date', $filters['date']);                            
                        }
                        
                        // Filter by category if provided
                        if (!empty($filters['customer'])) {
                            $q->where('customer', $filters['customer']);                            
                        }

                        // Filter by status if provided
                        if (!empty($filters['status'])) {
                            $q->whereHas('latestStatus', function ($statusQuery) use ($filters) {
                                $statusQuery->where('accounting_document_status_id', $filters['status']);
                            });
                        }
                                    
                    })                    
                    ->get()
                    ->groupBy('location_id'); 
        
        #dd($query);
        foreach ($query as $location_id => $location) {
            $documents[] = [Location::find($location_id)->title];

            foreach ($location as $doc) {
                $status = $doc->latestStatus;
                $documents[] = [
                    $doc->reference,
                    date('d-m-Y', strtotime($doc->accounting_document_date)),
                    $doc->customer,
                    $doc->total_ht,
                    $doc->discount_price,
                    $doc->tva_price,
                    $doc->total_ttc,
                    $request->type == 'export' ? $status->accounting_document_status : $status->toArray()
                ];
            }
        }

        #dd($documents);

        if($request->type == 'export'){
            $filename = "{$filters['document_type']}.csv";
            Excel::store(new DocumentExport($documents), $filename, 'public');            
            $link = asset("storage/{$filename}");
            $type = 'Exportation';
        }else{
            $pdf = (new AccountingDocService())->printlistdocument($documents, $filters['document_type']);            
            $link = $pdf['url'];
            $type = 'Impréssion';
        }

        return response()->json([
            'status' => 'success',
            'message' => "$type éffectuée avec succès.",
            'url' => $link
        ]);
    }
        
}