<?php

namespace modules\sales\Http\Controllers;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Session;
use modules\catalogs\Models\ProductLocation;
use modules\catalogs\services\CategoryService;
use modules\catalogs\services\ProductService;
use modules\crm\Models\BusinessContact;
use modules\crm\Models\BusinessContactTransaction;
use modules\crm\services\CrmService;
use modules\location\Models\Location;
use modules\sales\Models\AccountingDocumentPayment;
use modules\sales\Models\Caisse;
use modules\sales\Models\CaisseStatus;
use modules\sales\Models\CaisseStory;
use modules\sales\Models\CaisseTransaction;
use modules\sales\Models\Cart;
use modules\sales\Models\CartDetail;
use modules\sales\Models\PaymentMethod;
use modules\sales\Models\Receipt;
use modules\sales\Models\ReceiptDetail;
use modules\sales\Models\ReceiptPayment;
use modules\sales\services\BasketService;
use modules\sales\services\CaisseService;
use modules\sales\Services\ReceiptService;

class salesController extends Controller
{
    protected $basket;
    public function __construct(BasketService $basket)
    {
        $this->basket = $basket;
        
        Receipt::where('status', 'draft')
            ->where('created_at', '<', date_now()->subMinutes(30))
            ->delete();            
    }

    public function list(Request $request) {        
        $auth = Auth::user();
        $datastatus = (new ReceiptService())->summarizeReceiptsByStatus();        
        
        $page = isset($request->pagesize) ? $request->pagesize : 25;
        $receipts = (new ReceiptService())->receipts([], $page);
        $totals = (new ReceiptService())->totals([], $page);

        /*$p = $auth->getAllPermissions();
                    
        $permission_destroy = $p->contains('name', "sales.{$type}.destroy");
        if (!$permission_destroy) {                
            $_status = $_status->reject(fn($item) => $item->cancelled == 1);                
        }

        $permissions = array_values($p->filter(function ($permission) {
            return str_contains($permission->name, request()->type);
        })->toArray());*/

        if(is_null($auth->location_id)){
            $locations = Location::where('status', 'active')->get();
        }else{
            $locations = Location::where('id', $auth->location_id)->get();
        }

        return response()->json([
            'status' => 'success',
            'receipt_status' => $datastatus,
            'receipts' => $receipts,
            'totals' => $totals,
            'locations' => $locations,
            'auth' => $auth,
            'permissions' => []
        ]);
    }

    public function index(Request $request)
    {                                
        if(Session::has('caisse_id')){
            $caisse_id = Session::get("caisse_id");
            $caisse = CaisseService::status($caisse_id);

            if($caisse['status'] == 'close'){
                return Redirect::route('app.receipt.caisse.open');
            }
                        
            if(Session::has("vente_token")){
                if($request->ajax()){
                    $token = Session::get("vente_token");                    
                    $locations = Location::where('type', 'site')->select('id', 'type', 'title')->get();
                    $location = my_location();

                    $customers = CrmService::customers();        
                    return response()->json([
                        'settings' => settings(),
                        'locations' => [
                            'sites' => $locations,
                            'selected' => $location
                        ],
                        'caisse' => [
                            'data' => Caisse::find($caisse_id),
                            'amount' => $caisse["amount"]
                        ],
                        'customers' => $customers->toArray()
                    ]);
                }
                
                return view('sales::receipt.index');
            }else{
                return Redirect::route('app.receipt.caisse.open');                
            }

            
        }else{
            return Redirect::route('app.receipt.caisse.open');
        }
    }

    public function detail(Request $request){
        $auth = Auth::user();
        $token = $request->token;
        
        $receipt = Receipt::where('token', $token)->with(['payments', 'details'])->first();
        return response()->json([
            'status' => 'success',
            'auth' => $auth,
            'receipt' => $receipt
        ]);
    }
    
    public function openCaisse(Request $request)
    {
        if($request->isMethod('POST')){
            #dd($request->all());            
            $caisse = CaisseService::open($request);
            $caisse_name = $caisse['caisse']['data']['title'];

            $token = generateString(60);
            Session::put("vente_token", $token);
            Session::save();

            return response()->json([
                'status' => 'success',
                'caisse' => $caisse,
                'url' => [
                    'sale' => route('app.receipt.index')
                ],
                'message' => "Caisse [{$caisse_name}] ouvert succès"
            ]);
        }

        if($request->ajax()){
            $locations = Location::where('type', 'site')->select('id', 'type', 'title')->get();
            $location = my_location();      
            $caisses = Caisse::where('status', 'active')->get();

            return response()->json([
                'status' => 'success',
                    'locations' => [
                    'sites' => $locations,
                    'selected' => $location
                ],
                'caisses' => $caisses,
                'settings' => settings()
            ]);
        }

        return view('sales::receipt.open');
    }  
    
    public function caisseStatus(Request $request)
    {        
        $caisse_id = $request->input('caisse');        
        $location_id = $request->input('location');        

        $status = CaisseService::status($caisse_id);
        $caisse = CaisseStatus::where('location_id', $location_id)->where('caisse_id')->orderByDesc('created_at')->first();
        
        return response()->json([
            'status' => 'success',
            'caisse' => [
                'status' => $status,
                'data' => $caisse
            ]
        ]);
    } 

    public function store(Request $request)
    {
        #$num = $this->caisses->numerotation();
        #dd($request->all());
        try {
            DB::beginTransaction();

            $token = null;
            if(Session::has("vente_token")){
                $token = Session::get('vente_token');
            }else{
                $message = "<p class='mb-1'>Une erreur s'est produite lors de la confirmation de la vente.</p><p class='mb-1'>Veuillez rafraichir la page et réessayer de nouveau.</p>";
                return response()->json([
                    "status" => "error",
                    "message" => $message
                ], 500);
            }            
    
            if (!isset($request->with_delivery)) {
                $cart = Cart::where('token', $token)->first();            
                if ($cart) {
                    $cart->update(['delivery_price' => 0]);            
                    CartDetail::where('cart_id', $cart->id)->update([
                        'delivery_price' => 0,
                        'delivery_price_total' => 0,
                    ]);
                }
            }
            
            $customer = CrmService::customers(['id' => $request->customer['id']])->first();            
            $user = [
                'id' => Auth::user()->id,
                'name' => Auth::user()->name,
            ];
                     
            $location = $request->location;            

            $caisse_status = CaisseStatus::where('id', Session::get('caisse_open_id'))->first();
            $caisse_id = $caisse_status->caisse_id;
            $caisse_name = $caisse_status->caisse;

            $customer = $request->customer;

            $cart = Cart::where('token', $token)->with('details.product')->first();
            $priceht = $cart->details->sum('total_price_ht');
            $pricettc = $cart->details->sum('total_price_ttc');
            $pricedicount = $cart->details->sum('discount_price');
            $pricetva = $cart->details->sum('tva_price');
            $pricedelivery = $cart->details->sum('delivery_price_total');

            $insert = [
                "status" => "draft",

                "caisse_status_id" => $caisse_id,

                "location_id" => $location['id'],
                "location" => $location['title'],

                "customer_id" => $customer['id'],
                "customer" => $customer['title'],
                'customer_email' => $customer['email'],
                'customer_phone' => $customer['phone'],
                'customer_address' => $customer['address'],

                "total_ht" => $priceht,
                
                "tva_price" => $pricetva,

                "has_discount" => Session::has('has_discount'),
                "discount_price" => $pricedicount,
                #"discount" => $details["remise_percent"] ?? 0,
                
                "total_ttc" => $pricettc,

                'has_delivery' => isset($request->with_delivery),
                'delivery_price' => isset($request->with_delivery) ? $pricedelivery : 0,
                
                "observation" => $request->observation,

                "user" => json_encode($user)
            ];                      
    
            $ticket = Receipt::where("token", $token)->first();
            if(!is_null($ticket)){                                
                $insert["updated_at"] = date_now();
                $ticket->update($insert);
            }else{
                $insert['token'] = $token;
                $insert["created_at"] = date_now();
                $insert["updated_at"] = date_now();

                $ticket = Receipt::create($insert);
            }
            $ticket_id = $ticket->id;
    
            ReceiptDetail::where("token", $token)->delete();                                                
            foreach($cart->details as $item){                
                $insert_detail = [
                    "receipt_id" => $ticket_id,

                    "token" => $token,
                    
                    'product_id' => $item['product_id'],                         
                    'product' => $item['product_title'], 
                    'product_reference' => $item['product_reference'], 
                    'product_image' => $item['product_image'], 

                    'quantity' => $item['qty'], 
                    
                    'unite_id' => $item['unite_id'], 
                    'unite' => $item['unite'], 

                    'price' => $item['price'],
                    'total_ht' => $item['total_price_ht'],
                    
                    'discount_by' => $item['discount_by'], 
                    'discount' => $item['discount'], 
                    'discount_of' => $item['discount_of'], 
                    'discount_type' => $item['discount_type'], 
                    'discount_price' => $item['discount_price'], 

                    'tva_rate' => $item['tva'], 
                    'tva_price' => $item['tva_price'], 

                    'delivery_price' => $item['delivery_price'], 

                    'total_ttc' => $item['total_price_ttc'],

                    "created_at" => date_now(),
                    "updated_at" => date_now(),
                ];

                ReceiptDetail::create($insert_detail);
            }
            
            DB::commit();

            
            $payment_methods = PaymentMethod::all();
            $paytoken = generateString(60);
            Session::put('paytoken', $paytoken);
            Session::save();

            return response()->json([
                "status" => "success",
                "message" => "Ticket de caisse bien enregistré avec succès",                
                'payment_methods' => $payment_methods,
                "ticket" => [
                    "id" => $ticket_id,
                    'paytoken' => $paytoken,
                    "token" => $token,
                    "montant_ht" => $priceht,
                    "montant_ttc" => $pricettc
                ]
            ]);
        } catch (\Throwable $th) {
            DB::rollBack();
            throw $th;
        }
    }

    public function payment(Request $request){        
        $reponse = (new ReceiptService())->processPayment($request);
        
        if($reponse['status'] == 'success'){
            $location = $reponse['location'];
                    
            Session::remove('vente_token');
            Session::remove('paytoken');
            Session::has('has_discount');

            $token = generateString(60);
            Session::put("vente_token", $token);
            Session::save();

            $categories = (new CategoryService())->categories();
            $products = ProductService::products(['location' => $location['id']]);
            
            $reponse['categories'] = [
                'data' => $categories['categories'],
                'parent' => $categories['parent'],
                'child' => false,
            ];
            $reponse['products'] = $products;
            $reponse['location'] = $location;
            $reponse['caisse'] = [
                'data' => Caisse::find(Session::get('caisse_open_id')),
                'amount' => $reponse["sold"]
            ];

            unset($reponse['sold']);

            return response()->json($reponse, 200);
        }else{            
            return response()->json($reponse, $reponse['code']);
        }
        
    }
    

}