<?php
namespace modules\sales\services;

use Illuminate\Support\Facades\Auth;
use modules\catalogs\services\ProductService;
use modules\catalogs\services\StockService;
use modules\crm\Models\BusinessContactTransaction;
use modules\sales\Models\AccountingDocument;
use modules\sales\Models\AccountingDocumentPayment;
use modules\sales\Models\AccountingDocumentStatus;
use modules\sales\Models\PaymentMethod;

class CreditService
{
    public function handleCreditDocument($document, $status)
    {        
        #ajuster compte client, regarder si ça existe déjà                
        $exist = BusinessContactTransaction::where([
                    'business_contact_id' => $document->customer_id,
                    'document_id' => $document->id,
                    'transaction_type' => 'out',
                ])->first(); 
                  
        if(is_null($exist)){
            $desc = "Facture avoir #{$document->reference}";
            $amount = (float)$document->total_ttc * -1;

            BusinessContactTransaction::create([
                'business_contact_id' => $document->customer_id,
                'business_contact_name' => $document->customer,
                'business_contact_type' => 'customer',
                'transaction_type' => 'out',
                'document_type' => 'credit',
                'document_id' => $document->id,
                'document_reference' => $document->reference,
                'document_amount' => $amount,
                'description' => $desc,
                'amount' => $amount,
                "created_at" => date_now(),
                "updated_at" => date_now(),
            ]);
        }

        #dd($document);
        $this->docHasStockExitAndPayment($document, $document->accounting_document_id, $status);        
    }

    public function docHasStockExitAndPayment(AccountingDocument $document, $linkedDocumentId, $status) {
        #dd($document, $linkedDocumentId);
        if((int)$status['pay'] == 1){
            $document = AccountingDocument::where('id', $document->id)->with(['details', 'status'])->first();
            $this->verfiDocStock($document);

            if(!is_null($linkedDocumentId)){
                $linkedDocument = AccountingDocument::where('id', $linkedDocumentId)->with(['details', 'status'])->first();                            
                $this->verifDocPayment($linkedDocument, $linkedDocument->total_ttc);
            }            
        }
    }

    protected function verfiDocStock(AccountingDocument $doc){
        $document = $doc->toArray();
        $reference = $document['reference'];
        
        $linkedCurrentStatus = AccountingDocumentStatus::find($document['status'][0]['accounting_document_status_id']);

        if((int)$linkedCurrentStatus['use_default'] != 1 || (int)$linkedCurrentStatus['cancelled'] != 1){
            //ajuster les stocks
            $stockService = new StockService();
            foreach ($document['details'] as $key => $detail) {
                if($detail['row_type'] == 'product'){
                    $quantity = $detail['qty'];
                    $product_id = $detail['product_id'];
                    $location_id = $document['location_id'];
                    $price = $detail['price_ttc'];

                    $product = (new ProductService())->products([
                        'id' => $product_id,
                        'location' => $location_id
                    ])->first();
                    #dd($product->toArray());

                    $stock_actual = $product['stock'][0]->stock;
                    $stock_final = (double)$stock_actual + $quantity;

                    $where = [
                        'product_id' => $product_id,
                        'location_id' => $location_id
                    ];  

                    $desc = "Retour produit dans facture avoir #{$reference}";
                    
                    $stockService->update([
                        'product_id' => $product_id, 
                        'location_id' => $location_id, 
                        'quantity' => $quantity, 
                        'price' => $product['supplier_price'][0]['price']
                    ], 'entry');

                    /*$stockService->createUpdateControl([
                        'type' => 'in',
                        'where' => $where,
                        'location_id' => $location_id,
                        'product_id' => $product_id,
                        'product_name' => $detail['product'],
                        'stock_actual' => $stock_actual,
                        'quantity' => $quantity,
                        'stock_final' => $stock_final,
                        'title' => $desc,
                    ]);*/

                    $stockService->logStockStory([
                        'product_id' => $product_id,
                        'product_name' => $detail['product'],
                        'location_id' => $location_id,                    
                        'title' => $desc,
                        'stock_actual' => $stock_actual,                 
                        'quantity' => $quantity,
                        'stock_final' => $stock_final,
                        'token' => $reference,
                    ]);
                }
            }
        }
    }

    protected function verifDocPayment(AccountingDocument $document, float $amount){
        $documentId = $document->accounting_document_id;
        $exist = AccountingDocumentPayment::where('accounting_document_id', $documentId)->first();
        if(!is_null($exist)){
            $desc = "Paiement facture avoir #{$exist->reference}";
            #enregistrer le paiement de l'avoir
            $payment_method = PaymentMethod::where('type', 'credit')->where('is_default', 1)->first();
            AccountingDocumentPayment::create([
                "accounting_document_id" => $document->id,
                "reference" => $document->reference,
                "user_id" => Auth::user()->id,
                "username" => Auth::user()->name,
                "payment_method_id" => $payment_method->id,
                "payment_method" => $payment_method->title,
                "amount" => $amount,
                "observation" => $desc,
                "created_at" => date_now(),
                "updated_at" => date_now(),
            ]);

            #ajuster le compte du client
            BusinessContactTransaction::create([
                'business_contact_id' => $document->customer_id,
                'business_contact_name' => $document->customer,
                'business_contact_type' => 'customer',
                'transaction_type' => 'in',
                'document_type' => 'credit',
                'document_id' => $document->id,
                'document_reference' => $document->reference,
                'document_amount' => $document->total_ttc,
                'description' => $desc,
                'amount' => $amount,
                "created_at" => date_now(),
                "updated_at" => date_now(),
            ]);
        }
    }
}