<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::create("accounting_documents", function (Blueprint $table) {
            $table->id();
            $table->enum("document_type", ["invoice", "order", "delivery", "return", "credit", "quote"]);
            
            $table->enum("link_to", ["none", "order", "delivery", "quote", "return"]);
            $table->unsignedBigInteger("accounting_document_id")->nullable();
            $table->string("numero")->nullable();
            $table->string("reference")->nullable();
            $table->dateTime("accounting_document_date");
            $table->dateTime("accounting_document_release_date");
            
            $table->unsignedBigInteger("customer_id")->nullable();
            $table->string("customer")->nullable();
            $table->string("customer_email")->nullable();
            $table->string("customer_phone")->nullable();
            $table->text("customer_address")->nullable();
            
            $table->enum("discount_by", ["percent", "amount"])->nullable();
            $table->double("discount_rate")->default(0);
            $table->double("discount_price")->default(0);
            $table->double("tva_rate")->default(0);
            $table->double("tva_price")->default(0);
            
            $table->double("total_ht")->default(0);
            $table->double("total_ttc")->default(0);

            $table->string("slug")->nullable();
            $table->boolean("validate")->default(0);

            $table->unsignedBigInteger("user_id")->nullable();
            $table->string("username")->nullable();

            $table->unsignedBigInteger("edited_by")->nullable();
            $table->string("edited_name")->nullable();

            $table->foreign("accounting_document_id")->on("accounting_documents")->references("id")->onDelete("set null");
            $table->foreign("customer_id")->on("business_contacts")->references("id")->onDelete("set null");
            $table->foreign("user_id")->on("users")->references("id")->onDelete("set null");
            $table->timestamps();
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::dropIfExists("accounting_documents");
    }
};
