<?php

namespace modules\stocks\Http\Controllers;

use App\Http\Controllers\Controller;
use GuzzleHttp\Psr7\Query;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use modules\catalogs\Models\ProductLocation;
use modules\catalogs\Models\Products;
use modules\catalogs\Models\ProductStock;
use modules\catalogs\Models\ProductSupplierPrice;
use modules\catalogs\services\CategoryService;
use modules\catalogs\services\ProductService;
use modules\catalogs\services\StockService;
use modules\location\Models\Location;
use modules\stocks\Models\Inventory;
use modules\stocks\Models\InventoryDetail;
use modules\stocks\Models\StockTransfert;
use modules\stocks\Models\StockTransfertDetail;

class inventoryController extends Controller
{
    public function index()
    {                
        Inventory::where('validate', 0)->delete();
        return view('stocks::inventory.index');
    }

    public function getinventory(Request $request) {
        $page = isset($request->pagesize) ? $request->pagesize : 25;
        $query = Inventory::query();

        if ($request->has('criteria')) {
            if ($request->criteria == 'reference') {
                $query->where('reference', 'LIKE', '%'.$request->keyword.'%');
            }
            if ($request->criteria == 'date') {
                $query->whereDate('inventory_date', $request->keyword);
            }
            if ($request->criteria == 'user') {
                $query->where('username', 'LIKE', "%".$request->keyword."%");
            }
            if ($request->criteria == 'status') {                
                $query->where('status', $request->keyword['value']);
            }
        }
        
        $query->orderByDesc('created_at');
        if ($page == 0) {
            $inventories = $query->get();
        } else {
            $inventories = $query->paginate($page);
        } 

        $auth = Auth::user();
        if(is_null($auth->location_id)){
            $locations = Location::where('status', 'active')->where('stock_management', 1)->get();
        }else{
            $locations = Location::where('id', my_location()->id)->where('stock_management', 1)->get();
        }

        return response()->json([
            'status' => 'success',
            'inventories' => $inventories->toArray(),
            'locations' => $locations
        ]);
    }

    public function create(Request $request) {
        try {
            DB::beginTransaction();

            $last = Inventory::whereNotNull("numero")
                    ->orderByDesc("created_at")
                    ->limit(1)
                    ->first();   
            $numero = !is_null($last) ? $last->numero : 0;

            $location = my_location();
            $user = Auth::user();
            $inventaire = Inventory::create([
                'location_id' => $location->id,
                'location' => $location->title,
                'numero' => (float)$numero + 1,
                'reference' => "INV.".date_now()->format('dmY').'-'.((float)$numero + 1),
                'inventory_date' => date_now(),
                'status' => "inprogress",
                'user_id' => $user->id,
                'username' => $user->name, 
                'created_at' => date_now(),
                'updated_at' => date_now(),
            ]);

            $slug = $inventaire->id."-".generateString(18);
            $inventaire->slug = $slug;
            $inventaire->save();

            DB::commit();

            return redirect()->route('app.stock.inventory.detail', ['slug' => $slug]);
        } catch (\Throwable $th) {
            DB::rollBack();
            throw $th;
        }
    }
    
    public function detail(String $slug, Request $request)
    {        
        if($request->ajax()){
            $inventory = Inventory::where('slug', $slug)->first(); // Récupère l'inventaire
            $location_id = $inventory->location_id; // Récupère l'ID de l'emplacement

            $rep = $inventory->details()->with([
                'product.categories',
                'product.locations' => function ($query) use ($location_id) {
                    $query->where('location_id', $location_id);
                }
            ])->paginate(50);                                   

            $detail = $inventory->toArray(); // Convertir en tableau
            $detail['details'] = $rep->toArray(); // Remplacer `details` par les données paginées


            $locations = Location::where('type', 'site')
                            ->where('stock_management', 1)
                            ->select('id', 'type', 'title', 'is_parent', 'has_delivery', 'stock_management',)->get();
            $location = my_location();            

            return response()->json([
                'status' => 'success',                
                'detail' => $detail,
                'locations' => [
                    'sites' => $locations,
                    'selected' => $location
                ]
            ]);
        }

        // $prod = ProductService::products([
        //     'with' => 'inventories-details',
        //     'inventory-slug' => $slug
        // ], 50);
        
        // /*$prod = Products::with([
        //     'inventoriesDetails' => function ($query) use ($slug) {
        //         $query->whereHas('inventory', function ($q) use ($slug) {
        //             $q->where('slug', $slug);
        //         });
        //     },
        //     'categories',            
        // ])->get();*/
        // dd($prod->toArray());

        return view('stocks::inventory.detail');
    }

    public function store(Request $request){
        try {            
            #dd($request->all());

            $request->validate([
                'product.id' => 'required',                
                'location.id' => 'required',                
                'product.regul.qty' => 'required',                
            ]);
            DB::beginTransaction();

            $auth = Auth::user();

            $slug = $request->slug;
            $product = $request->product;
            
            #$location = $request->location;
            #$prod = ProductService::products(['id' => $product['id']])->first();
            #$stock = $prod->stock->where('location_id', $location['id'])->first();
            
            $prod = Products::find($product['id']);
            $actual = $request->product['stock'];
            $regul = $request->product['regul'];
            $regulQty = $regul['qty'];
            $regulPrice = $regul['price'];
            $ecart = $regul['ecart'];            

            $inventory = Inventory::where('slug', $slug)->first();
            $exist = InventoryDetail::where('inventory_id', $inventory->id)->where('product_id', $product['id'])->first();

            if(is_null($exist)){
                InventoryDetail::create([
                    'inventory_id' => $inventory->id,
                    'product_id' => $product['id'],  
                    'product' => $product['designation'],
                    'product_category' => $product['category'],
                    'product_image' => $prod->image,
                    'product_reference' => $prod->reference,
                    'stock_actual' => $actual,
                    'stock_final' => $regulQty,
                    'stock_regul' => $regulQty,
                    'product_purchase_price' => $product['price'],
                    'purchase_price_regul' => $regulPrice,
                    'create_by' => json_encode([
                        'id' => $auth->id,
                        'name' => $auth->name,
                    ]),
                    'update_by' => json_encode([
                        'id' => $auth->id,
                        'name' => $auth->name,
                    ]),
                    'created_at' => date_now(),
                    'updated_at' => date_now(),
                ]);
            }else{
                InventoryDetail::where('id', $exist->id)->update([
                    'stock_actual' => $actual,
                    'stock_final' => $regulQty,
                    'stock_regul' => $regulQty,
                    'product_purchase_price' => $product['price'],
                    'purchase_price_regul' => $regulPrice,                    
                    'update_by' => json_encode([
                        'id' => $auth->id,
                        'name' => $auth->name,
                    ]),                    
                    'updated_at' => date_now(),
                ]);
            }

            Inventory::where('id', $inventory->id)->update([
                'validate' => 1
            ]);
            DB::commit();

            $detail = Inventory::where('slug', $slug)->with(['details'])->first()->toArray();
            return response()->json([
                'status' => 'success',
                'detail' => $detail
            ]);

        } catch (\Throwable $th) {
            DB::rollBack();
            throw $th;
        }
    }
    
    public function inventory_validate(Request $request){
        try {                        
            DB::beginTransaction();
            #dd($request->all());
            $auth = Auth::user();
            
            $id = $request->id;
            $query = Inventory::where('id', $id);
            $inventory = $query->with(['details' => function ($query) {
                            $query->orderByDesc('created_at');
                        }])->first();            
            
            $token = generateString(18);
            $stockService = new StockService();
            foreach ($inventory->details as $key => $detail) {
                $product_id = $detail->product_id;
                $location_id = $inventory->location_id;
                $productStock = ProductStock::where('product_id', $product_id)->where('location_id', $location_id)->first();                

                $product_name = $detail->product;
                $stock_actual = $productStock->stock;

                $description = "INVENTAIRE: #". $inventory->reference;
                $stockRegul = $detail->stock_regul;
                
                $stockService->update([
                    'product_id' => $product_id, 
                    'location_id' => $location_id, 
                    'quantity' => $stockRegul, 
                    'price' => $detail->purchase_price_regul
                ], 'inventory');

                $stockService->logStockStory([
                    'product_id' => $product_id,
                    'product_name' => $product_name,
                    'location_id' => $location_id,
                    'title' => $description,
                    'stock_actual' => $stock_actual,                 
                    'quantity' => $stockRegul,
                    'stock_final' => $stockRegul,
                    'token' => $token,
                ]);

                $stockService->createUpdateControl([
                    'type' => 'inventory',
                    'where' => [
                        'product_id' => $product_id,
                        'location_id' => $location_id
                    ],
                    'location_id' => $location_id,
                    'product_id' => $product_id,
                    'product_name' => $product_name,
                    'stock_actual' => $stock_actual,
                    'quantity' => $stockRegul,
                    'stock_final' => $stockRegul,
                    'title' => $description,
                ]);

            }

            $query->update([
                'inventory_date' => $request->date,
                'status' => 'validate',
                'updated_at' => date_now()
            ]);

            DB::commit();

            $detail = [];
            return response()->json([
                'status' => 'success',
                'detail' => $detail
            ]);

        } catch (\Throwable $th) {
            DB::rollBack();
            throw $th;
        }
    }

    public function document($slug)
    {                        
        $doc = (new Inventory())->printdocument($slug);
        return $doc['pdf']->setWarnings(false)->stream($doc['name'].'.pdf', array("Attachment" => false));
    }
    
    public function matrice(Request $request)
    {        
        $location = Location::where('slug', $request->location)->first();
        $doc = (new Inventory())->printmatrice($location);
        return $doc['pdf']->setWarnings(false)->stream($doc['name'].'.pdf', array("Attachment" => false));
    }

}