<?php

namespace modules\stocks\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Notifications\Notification;
use modules\stocks\Models\StockTransfert;

class StockTransferStatusUpdated extends Notification
{
    use Queueable;

    private $transfert;
    private $reference;

    /**
     * Create a new notification instance.
     *
     * @param  \modules\stocks\Models\StockTransfert  $transfert
     */
    public function __construct(StockTransfert $transfert, String $reference)
    {
        $this->transfert = $transfert;
        $this->reference = $reference;
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param  mixed  $notifiable
     * @return array
     */
    public function via($notifiable)
    {
        return ['database'];
    }

    /**
     * Get the array representation of the notification.
     *
     * @param  mixed  $notifiable
     * @return array
     */
    public function toDatabase($notifiable)
    {

        #dd($this->transfert);

        $statusMessages = [
            'pending' => "Transfert de stock du facture {$this->reference} est en attente.",
            'approved' => "Transfert de stock du facture {$this->reference} a été aprouvé.",
            'rejected' => "Transfert de stock du facture {$this->reference} a été rejeté.",
        ];

        return [
            'transfert_id' => $this->transfert->id,
            'status' => $this->transfert->status,
            'source' => $this->transfert->source_location_id,
            'destination' => $this->transfert->destination_location_id,
            'message' => $statusMessages[$this->transfert->status],
            'updated_at' => date_now(),
        ];
    }
}
