<?php

namespace modules\sales\services;

use Carbon\Carbon;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use modules\catalogs\Models\Products;
use modules\catalogs\services\ProductService;
use modules\catalogs\services\StockService;
use modules\location\Models\Location;
use modules\sales\Models\AccountingDocument;
use modules\sales\Models\AccountingDocumentDetail;
use modules\sales\Models\AccountingDocumentStatus;
use modules\sales\Models\Invoice;
use modules\sales\Models\InvoiceDetail;
use modules\sales\Models\InvoiceType;
use modules\stocks\Models\StockTransfert;
use modules\stocks\Models\StockTransfertDetail;

use Barryvdh\DomPDF\Facade\Pdf;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\View;
use modules\crm\Models\BusinessContactTransaction;
use modules\sales\Models\AccountingDocumentPayment;
use modules\sales\Models\PaymentMethod;
use modules\stocks\Notifications\StockTransferStatusUpdated;

class AccountingDocService
{
    
    public static function documenttype(){
        return [
            "invoice" => "Facture",
            "order" => "Bon de commande",
            "delivery" => "Bon de livraison", 
            "return" => "Bon de retour", 
            "credit" => "Avoirs", 
            "quote" => "Devis",
        ];
    }

    public function numero($type){        
        $last = AccountingDocument::where('document_type', $type)
                    ->where('validate', 1)
                    ->whereNotNull("reference")
                    ->orderByDesc("created_at")
                    ->limit(1)->first();        
        
        $lastnum = !is_null($last) ? $last->numero : 0;
        $index = $lastnum + 1;
        $num = auto_number($type, $index);

        return [
            "reference" => $num,
            "index" => $index
        ];
    }

    public function documents(string $type, array $data = [], int $page = 0){
        $relations = ['status', 'details', 'stories', 'payments', 'location'];
        if($type == 'invoice'){
            $relations[] = 'invoice_type';
        }
        #dd($relations);

        $res = AccountingDocument::with($relations)->where('document_type', $type);        
        if(Auth::user()->location_id != null){
            $res->where('accounting_documents.location_id', Auth::user()->location_id);
        }        

        if(!empty($data)){ 
            #dd($data);
            if(isset($data['document_for']) && $data['document_for'] != 'all'){
                $res->where('accounting_documents.document_for', $data['document_for']);
            }

            if(isset($data['date'])){
                $res->whereDate('accounting_documents.accounting_document_date', $data['date']);
            }
            
            if(isset($data['validate'])){
                $res->where('accounting_documents.validate', $data['validate']);
            }
            
            if(isset($data['id'])){
                $res->where('accounting_documents.id', $data['id']);
            }
            
            if(isset($data['location'])){
                $location = Location::where('slug', $data['location'])->first();
                $res->where('accounting_documents.location_id', $location->id);                
            }
            
            if(isset($data['slug'])){
                $res->where('accounting_documents.slug', $data['slug']);
            }

            if(isset($data['reference'])){
                $res->where('accounting_documents.reference', $data['reference']);
            }
            
            if(isset($data['customer_id'])){
                $res->where('accounting_documents.customer_id', $data['customer_id']);
            } 
            
            if(isset($data['customer'])){
                $res->where('accounting_documents.customer', "LIKE", "%".$data['customer']."%");
            } 

            if(isset($data['year'])){
                $res->whereDate('created_at', '>=', "{$data['year']['begin']}-10-01")
                    ->whereDate('created_at', '<=', "{$data['year']['end']}-09-30");
            }

            if(isset($data['status'])){
                $ch = $this->status([], ['accounting_document_status_id' => $data['status']]);
                $accounting_document_id = array_column($ch, 'accounting_document_id');
                $res->whereIn('accounting_documents.id', $accounting_document_id);
            }
        }

        if($page == 0){
            $documents = $res->orderByDesc('created_at')->get();
        }else{
            $documents = $res->orderByDesc('created_at')->paginate($page);
        }
        
        #dd($documents->toArray());

        $documents->transform(function($item, $key) use ($type){      
            #dd($item);
            if($item->document_for == 'site'){
                $location = Location::find($item->customer_id);
                $item->customer = $location->title;
            }

            $status = $item->status;
            $item->status = $status;
            $currentStatusId = $status[0]->accounting_document_status_id;
            $currentStatus = AccountingDocumentStatus::find($currentStatusId);
            $item->status[0]['edited'] = (int)$currentStatus->edited == 1;

            $item->current_status = $currentStatusId;
            $used_status = array_column($status->toArray(), "accounting_document_status_id");
            $item->used_status = $used_status;
            
            $pstatus = $this->statusUsed($type, $status[0]->accounting_document_status_id);
            #dd($pstatus);

            $p = Auth::user()->getAllPermissions();
            $datastatus = AccountingDocumentStatus::whereNotIn('id', $pstatus)->where('type', $type)->get();
            $permission_destroy = $p->contains('name', "sales.{$type}.destroy");
            if (!$permission_destroy) {                
                $datastatus = $datastatus->reject(fn($item) => $item->cancelled == 1);                
            }
            $item->datastatus = $datastatus;
            
            if((int)$status[0]->accounting_document_status_id == 4 OR (int)$status[0]->accounting_document_status_id == 5){
                
            }else{
                $release_date = Carbon::parse($item->accounting_document_release_date)->format('Y-m-d');
                $day_diff = Carbon::now()->diff($release_date);
                
                $item->release_in_days = [
                    'class' => (int)$day_diff->invert == 0 ? "text-blue-700" : "text-red-700", 
                    'text' => (int)$day_diff->invert == 0 ? "Expiré dans {$day_diff->days}j" : "Retard de {$day_diff->days}j",
                    'invert' => $day_diff->invert
                ]; 
            }            
            
            $item->details = $item->details;
            $item->stories = $item->stories;

            $payments = $item->payments;
            $payment = $payments->sum('amount');            

            $item->payments = $payments;
            $item->payment_total = $payment;
            
            $rap = (float)$payment - (float)$item->total_ttc;
            $item->rap = $rap;

            $item->customer_status = $rap != 0 ? "Impayé" : "Payé";

            #dd($item);
            #NEXT & PREVIOUS DOCUMENT
            $qn = AccountingDocument::where('document_type', $item->document_type)
            ->when(Auth::user()->location_id != null, function ($query) {
                return $query->where('accounting_documents.location_id', Auth::user()->location_id);
            });

            $next = (clone $qn)->where('id', '>', $item->id)->where('validate', 1)->first();
            $previous = (clone $qn)->where('id', '<', $item->id)->where('validate', 1)->orderByDesc('created_at')->first();          

            $item->next = $next;
            $item->previous = $previous;

            $ref = $item->reference;
            $name = str_replace(" ", "_", $ref).".pdf";
            $pathpdf = public_path("pdf/invoice/{$name}");            
            if(!File::exists($pathpdf)){
                $pdf = route('app.sales.documents.document', ['type' => $type, 'slug' => $item->slug]);
            }else{
                $pdf = asset("pdf/invoice/{$name}"); 
            }
            $item->pdf = $pdf;

            return $item;
        });
        #dd($documents);

        $documents->filter(function ($invoice) {
            return $invoice->rap < 0;
        });        
        
        return $documents;
    }

    public function customerInvoiceReport($locations){
        $return = [];
        foreach ($locations as $key => $location) {
            // Création de la base de la requête pour les factures
            $invoices = AccountingDocument::query()
                ->where('document_type', 'invoice')
                ->where('document_for', 'customer')
                ->where('location_id', $location->id)
                ->where('total_ttc', '>', 0); // Filtrer uniquement les factures avec montant > 0

            $impayes = (new AccountingDocService())->customerInvoiceUnpaid($location->id);
            $en_cours = (new AccountingDocService())->customerInvoiceAwaitingPayment($location->id);
                                  
            $ca_globale = $invoices->sum('total_ttc');

            // Ajout des résultats dans le tableau de retour
            $return[] = [
                'id' => $location->id,
                'title' => $location->title,
                'en_attente_paiement' => [
                    'count' => $en_cours->count() - $impayes->count(),
                    'sum' => (float)$en_cours->sum('total_ttc') - (float)$impayes->sum('total_ttc')
                ],
                'encours_clients' => [
                    'count' => $en_cours->count(),
                    'sum' => $en_cours->sum('total_ttc')
                ],
                'impayes' => [
                    'count' => $impayes->count(),
                    'sum' => $impayes->sum('total_ttc')
                ],
                'ca_globale' => $ca_globale,
            ];
        }
        
        return $return;
    }


    public function status(array $year = [], array $data = [])
    {
        $bindings = [];        
        $query = "
            WITH RankedStatus AS (
                SELECT
                    accounting_document_id,
                    accounting_document_status_id,
                    created_at,
                    ROW_NUMBER() OVER (PARTITION BY accounting_document_id ORDER BY created_at DESC) AS rn
                FROM
                    accounting_documents_status_logs
            )
            SELECT
                rs.accounting_document_id,
                rs.accounting_document_status_id,                
                rs.created_at,
                i.accounting_document_date,
                i.total_ht,
                i.total_ttc,
                COALESCE(SUM(ip.amount), 0) AS total_paid,
                COALESCE(SUM(ip.amount), 0) - i.total_ttc AS rap
            FROM
                RankedStatus rs
            INNER JOIN
                accounting_documents i ON i.id = rs.accounting_document_id
            LEFT JOIN
                accounting_documents_payments ip ON ip.accounting_document_id = rs.accounting_document_id
            WHERE 
                rs.rn = 1 
                AND i.validate = 1";

        if (!empty($data['document_for'])) {
            $query .= " AND i.document_for = ?";
            $bindings[] = $data['document_for'];
        }

        // Ajout de la condition location_id
        if (Auth::user()->location_id != null) {
            $query .= " AND i.location_id = ?";
            $bindings[] = Auth::user()->location_id;
        }

        // Ajout des filtres dynamiques
        if (!empty($data)) {
            if (isset($data['accounting_document_status_id'])) {
                if (is_array($data['accounting_document_status_id'])) {
                    $placeholders = implode(',', array_fill(0, count($data['accounting_document_status_id']), '?'));
                    $query .= " AND rs.accounting_document_status_id IN ($placeholders)";
                    $bindings = array_merge($bindings, $data['accounting_document_status_id']);
                } else {
                    $query .= " AND rs.accounting_document_status_id = ?";
                    $bindings[] = $data['accounting_document_status_id'];
                }
            }

            if (isset($data['customer_id'])) {
                $query .= " AND i.customer_id = ?";
                $bindings[] = $data['customer_id'];
            }

            if (isset($data['accounting_document_id'])) {
                if (is_array($data['accounting_document_id']) && !empty($data['accounting_document_id'])) {
                    $placeholders = implode(',', array_fill(0, count($data['accounting_document_id']), '?'));
                    $query .= " AND rs.accounting_document_id IN ($placeholders)";
                    $bindings = array_merge($bindings, $data['accounting_document_id']);
                }
            }

            if (isset($data['document_type'])) {
                $query .= " AND i.document_type = ?";
                $bindings[] = $data['document_type'];
            }

            if (isset($data['location_id'])) {
                $query .= " AND i.location_id = ?";
                $bindings[] = $data['location_id'];
            }
        }
        #dd($data, $year);

        if (isset($year['month']) && isset($year['begin'])) {
            $month = str_pad($year['month'], 2, '0', STR_PAD_LEFT); // Assurer que le mois est sous format "MM"            
            $currentYear = $year['begin'];
            $query .= " AND DATE_FORMAT(i.accounting_document_date, '%Y-%m') = ?";
            $bindings[] = "$currentYear-$month";
        }

        // Ajout du filtrage par année
        if (!empty($year) && !isset($year['month'])) {            
            $begin = $year['begin'] . "-01-01";
            $end = $year['end'] . "-12-31";
            $query .= " AND rs.created_at BETWEEN ? AND ?";
            $bindings[] = $begin;
            $bindings[] = $end;
        }        

        // Ajout de la clause GROUP BY
        $query .= " GROUP BY 
                        rs.accounting_document_id, 
                        rs.accounting_document_status_id, 
                        rs.created_at, 
                        i.accounting_document_date, 
                        i.total_ht, 
                        i.total_ttc";

        // Exécution de la requête avec les bindings
        return DB::select($query, $bindings);
    }

    public function all_status($type, array $data = []){
        $f = ['validate' => 1];
        if(!empty($data)){
            if(isset($data['location'])){                
                $f['location'] = $data['location'];
            }
        }
        
        $all = $this->documents($type, $f);
        
        $status['count'][] = [
            "id" => 0,
            "title" => 'Toutes',
            "icon" => null,
            "background" => "#FFFFFF",
            "color" => "#000000",
            "count" => count($all),
            "ht" => $all->sum('total_ht'),
            "ttc" => $all->sum('total_ttc'),
            "paid" => $all->sum('payment_total'),
            "rap" => $all->sum('rap'),
        ];
        
        $res = AccountingDocumentStatus::where('type', $type);
        $xstatus = $res->get();
       
        foreach ($xstatus as $item) {
            $filter['accounting_document_status_id'] = $item->id;
            if(isset($f['location'])){
                $location = Location::where('slug', $f['location'])->first();
                $filter['location_id'] = $location->id;
            }
            $_data = $this->status([], $filter);
            
            $status['count'][$item->id] = [
                "id" => $item->id,
                "title" => $item->title,
                "icon" => $item->icon,
                "background" => $item->background,
                "color" => $item->color,
                "count" => count($_data),
                "ht" => array_sum(array_column($_data, 'total_ht')),
                "ttc" => array_sum(array_column($_data, 'total_ttc')),
                "paid" => array_sum(array_column($_data, 'total_paid')),
                "rap" => array_sum(array_column($_data, 'rap')),
            ];
        }

        return $status;
    }

    public function statusUsed(string $type, int $statusUsedId): array
    {
        $statusMappings = [
            'invoice' => [
                1 => [1, 4],
                2 => [1, 2],
                3 => [1, 2, 3],
                4 => [1, 2, 3, 4],
            ],
            'credit' => [
                10 => [10, 12],
                11 => [10, 11],
                12 => [10, 11, 12]
            ],
            'quote' => [
                6 => [6, 8, 9], // Brouillon
                7 => [6, 9],    // Envoyée
                8 => [6, 7, 9], // Acceptée
                9 => [6, 7, 8], // Expirée
            ],
        ];

        return $statusMappings[$type][$statusUsedId] ?? [];
    }

    public function duplicateParentInvoice(int $documentId, string $stockAction)
    {
        $invoice = Invoice::where('accounting_document_id', $documentId)->first();
        #dd($invoice);
        if (!$invoice) {
            $document = AccountingDocument::findOrFail($documentId)->toArray();
            
            $invoiceType = InvoiceType::where('invoice_id', $documentId)->first();

            if ($invoiceType) {
                $document['reference_parent'] = $document['reference'] . '-1';
                $document['accounting_document_id'] = $documentId;

                $invoicetype = $invoiceType->invoice_type;
                $location = Location::findOrFail(
                    $invoicetype == 'customer' ? $document['location_id'] : $document['customer_id']
                );                

                $document['location_id'] = $location->id;
                $document['location'] = $location->title;

                $details = AccountingDocumentDetail::where('accounting_document_id', $documentId)->get();

                // Nettoyage des totaux
                unset($document['total_ht'], $document['discount_price'], $document['tva_price'], $document['total_ttc'], $document['rap']);

                $invoice = Invoice::create($document);

                $totals = ['ht' => [], 'discount' => [], 'tva' => [], 'ttc' => [], 'delivery_price' => $document['delivery_price']];
                
                $stockTransfert = $this->createStockTransferIfRequired(
                                        $document, 
                                        $location
                                    );

                foreach ($details as $item) {
                    $totalsForItem = $this->calculateItemTotals($item, $document['document_for']);
                    #dd($totalsForItem, $item);

                    $totals['ht'][] = $totalsForItem['price_ht'];
                    $totals['discount'][] = $totalsForItem['discount'];
                    $totals['tva'][] = $totalsForItem['tva'];
                    $totals['ttc'][] = $totalsForItem['ttc'];

                    InvoiceDetail::create(array_merge($item->toArray(), [
                        'invoice_id' => $invoice->id,
                        'price_ht' => $totalsForItem['price_ht'],
                        'discount_price' => $totalsForItem['discount'],
                        'price_ttc' => $totalsForItem['ttc'],
                        'tva_price' => $totalsForItem['tva'],
                    ]));

                    #dd($stockAction == 'decrease' && $item->row_type == 'product');
                    if ($stockAction == 'decrease' && $item->row_type == 'product') {
                        $locat = $invoicetype == 'site' ? Location::where('is_parent', 1)->first() : $location;
                        $this->handleStockDecrease(
                            $document, 
                            $locat,
                            $item
                        );

                        if ($stockTransfert) {
                            $this->addStockTransferDetail($stockTransfert, $item);
                        }
                    }
                }

                $this->updateInvoiceTotals($invoice, $totals);
            }
        }

        return $invoice;
    }

    public function docHasStockExitAndPayment(AccountingDocument $document, int $linkedDocumentId, $status) {
        #dd($document);
        $linkedDocument = AccountingDocument::where('id', $linkedDocumentId)->with(['details', 'status'])->first();
        #dd($documentId, $document);

        if((int)$status['pay'] == 1){
            #si y a paiement            
            $this->verifDocPayment($linkedDocument, $linkedDocument->total_ttc);
        }else{
            #gestion de stock
            $this->verfiDocStock($linkedDocument);
        }
    }

    private function verfiDocStock(AccountingDocument $doc){
        $document = $doc->toArray();
        $reference = $document['reference'];
        
        $linkedCurrentStatus = AccountingDocumentStatus::find($document['status'][0]['accounting_document_status_id']);

        if((int)$linkedCurrentStatus['use_default'] != 1 || (int)$linkedCurrentStatus['cancelled'] != 1){
            //ajuster les stocks
            $stockService = new StockService();
            foreach ($document['details'] as $key => $detail) {
                if($detail['row_type'] == 'product'){
                    $quantity = $detail['qty'];
                    $product_id = $detail['product_id'];
                    $location_id = $document['location_id'];
                    $price = $detail['price_ttc'];

                    $product = (new ProductService())->products([
                        'id' => $product_id,
                        'location' => $location_id
                    ])->first();
                    #dd($product->toArray());

                    $stock_actual = $product['stock'][0]->stock;
                    $stock_final = (double)$stock_actual + $quantity;

                    $where = [
                        'product_id' => $product_id,
                        'location_id' => $location_id
                    ];  

                    $desc = "Retour produit dans facture avoir #{$reference}";
                    
                    $stockService->update([
                        'product_id' => $product_id, 
                        'location_id' => $location_id, 
                        'quantity' => $quantity, 
                        'price' => $product['supplier_price'][0]['price']
                    ], 'entry');

                    /*$stockService->createUpdateControl([
                        'type' => 'in',
                        'where' => $where,
                        'location_id' => $location_id,
                        'product_id' => $product_id,
                        'product_name' => $detail['product'],
                        'stock_actual' => $stock_actual,
                        'quantity' => $quantity,
                        'stock_final' => $stock_final,
                        'title' => $desc,
                    ]);*/

                    $stockService->logStockStory([
                        'product_id' => $product_id,
                        'product_name' => $detail['product'],
                        'location_id' => $location_id,                    
                        'title' => $desc,
                        'stock_actual' => $stock_actual,                 
                        'quantity' => $quantity,
                        'stock_final' => $stock_final,
                        'token' => $reference,
                    ]);
                }
            }
        }
    }

    private function verifDocPayment(AccountingDocument $document, float $amount){
        $documentId = $document->accounting_document_id;
        $exist = AccountingDocumentPayment::where('accounting_document_id', $documentId)->first();
        if(!is_null($exist)){
            $desc = "Paiement facture avoir #{$exist->reference}";
            #enregistrer le paiement de l'avoir
            $payment_method = PaymentMethod::where('type', 'credit')->where('is_default', 1)->first();
            AccountingDocumentPayment::create([
                "accounting_document_id" => $document->id,
                "reference" => $document->reference,
                "user_id" => Auth::user()->id,
                "username" => Auth::user()->name,
                "payment_method_id" => $payment_method->id,
                "payment_method" => $payment_method->title,
                "amount" => $amount,
                "observation" => $desc,
                "created_at" => date_now(),
                "updated_at" => date_now(),
            ]);

            #ajuster le compte du client
            BusinessContactTransaction::create([
                'business_contact_id' => $document->customer_id,
                'business_contact_name' => $document->customer,
                'business_contact_type' => 'customer',
                'transaction_type' => 'in',
                'document_type' => 'credit',
                'document_id' => $document->id,
                'document_reference' => $document->reference,
                'document_amount' => $document->total_ttc,
                'description' => $desc,
                'amount' => $amount,
                "created_at" => date_now(),
                "updated_at" => date_now(),
            ]);
        }
    }

    private function createStockTransferIfRequired(array $document, Location $location)
    {
        #dd($document);
        if ($document['document_for'] == 'site') {
            $user = Auth::user();

            $source = Location::where('is_parent', 1)->firstOrFail();        
            $destination = $location;
            
            $invoice = InvoiceType::where('invoice_id', $document['id'])->first();   
            $response = StockTransfert::create([
                'document_id' => $document['id'],
                'document' => $document['reference'],
                'source_location_id' => $source->id,
                'destination_location_id' => $destination->id,
                'source_location' => $source->title,
                'destination_location' => $destination->title,
                'slug' => generateString(18),
                'requested_at' => date_now(),
                'delivery_price' => $invoice->delivery_price,
                'user_id' => $user->id,
                'username' => $user->name,
            ]);                    

            $transfert = StockTransfert::findOrFail($response->id);
            if($source){                
                $source->notify(new StockTransferStatusUpdated($transfert, $document['reference']));
            }

            if($destination){
                $destination->notify(new StockTransferStatusUpdated($transfert, $document['reference']));
            }

            return $transfert;
        }

        return null;
    }

    private function calculateItemTotals($item, $type)
    {
        $priceHt = $item->row_type == 'product' ? $this->calculateProductMargin($item, $type) : 0;
        $discount = $item->discount_by == 'percent' ? ($priceHt * $item->discount_rate / 100) : $item->discount_price;
        $tvaPrice = $priceHt * ((float)$item->tva_rate / 100);
        $totalTtc = $priceHt - $discount + $tvaPrice;

        return [
            'price_ht' => $priceHt,
            'discount' => $discount,
            'tva' => $tvaPrice,
            'ttc' => $totalTtc,
        ];
    }

    private function calculateProductMargin($item, $type)
    {        
        if($type == 'site'){
            return (double)$item->price_ht;
        }else{
            $product = Products::with('categories')->findOrFail($item->product_id);
            $category = $product->categories->whereNotNull('parent_id')->last();
            $marginRate = (double)($category->parent_marge ?? 0) / 100;

            $priceHt = ((double)$item->price_ht * $marginRate); # * (double)$item->qty;
            return $priceHt;
        }
    }

    private function handleStockDecrease(array $document, Location $location, $item)
    {
        $stockService = new StockService();
        $product = ProductService::products([
            'id' => $item->product_id,
            'location' => $location->id,
        ])->first();

        $stockActual = $product->stock[0]->stock ?? 0;
        $stockFinal = $stockActual - $item->qty;        

        if ((int)$location->stock_management != 1) {
            $location = Location::where('is_parent', 1)->firstOrFail();
        }
        #dd($location);

        $stockService->update([
            'product_id' => $item->product_id,
            'location_id' => $location->id,
            'quantity' => $item->qty,
        ], 'exit');

        $this->logStockMovement($stockService, $document, $location, $item, $stockActual, $stockFinal);        
    }

    private function logStockMovement($stockService, $document, $location, $item, $stockActual, $stockFinal)
    {
        $transfertTitle = "";
        if($document['document_for'] == "site"){
            $transfertTitle = " ET TRANSFERT";
        }
        $stockService->createUpdateControl([
            'product_id' => $item->product_id,
            'product_name' => $item->product,
            'location_id' => $location->id,
            'title' => 'VENTE '.$transfertTitle.' #' . $document['reference'],
            'stock_actual' => $stockActual,
            'quantity' => $item->qty,
            'stock_final' => $stockFinal,
            'type' => 'out',
        ]);

        $stockService->logStockStory([
            'product_id' => $item->product_id,
            'product_name' => $item->product,
            'location_id' => $location->id,
            'title' => 'VENTE '.$transfertTitle.' #' . $document['reference'],
            'stock_actual' => $stockActual,
            'quantity' => $item->qty,
            'stock_final' => $stockFinal,
            'token' => $document['slug'],
        ]);
    }

    private function addStockTransferDetail($stockTransfert, $item)
    {
        StockTransfertDetail::create([
            'stock_transfer_id' => $stockTransfert->id,
            'product_id' => $item->product_id,
            'product_name' => $item->product,
            'quantity' => $item->qty,
            'unite_id' => $item->unite_id,
            'unite' => $item->unite,
            'price_ht' => $item->price_ht,
            'created_at' => date_now(),
            'updated_at' => date_now(),
        ]);
    }

    private function updateInvoiceTotals($invoice, $totals)
    {        
        $invoice->update([
            'total_ht' => array_sum($totals['ht']),
            'discount_price' => array_sum($totals['discount']),
            'tva_price' => array_sum($totals['tva']),
            'total_ttc' => array_sum($totals['ttc']) + $totals['delivery_price'],
        ]);
    }

    protected $cols = [
        'invoice' => [
            [
                'title' => 'Désignation',
                'width' => '35%',
                'align' => 'left',
                'weight' => 'bold'
            ],
            [
                'title' => 'PU HT',
                'width' => '14%',
                'align' => 'right',
                'weight' => 'bold'
            ],
            [
                'title' => 'Qté',
                'width' => '7%',
                'align' => 'center',
                'weight' => 'bold'
            ],
            [
                'title' => 'Total HT',
                'width' => '14%',
                'align' => 'right',
                'weight' => 'bold'
            ],
            [
                'title' => 'TVA',
                'width' => '7%',
                'align' => 'center',
                'weight' => 'bold'
            ],
            [
                'title' => 'Total TTC',
                'width' => '14%',
                'align' => 'right',
                'weight' => 'bold'
            ],
        ],
        'quote' => [
            [
                'title' => 'Désignation',
                'width' => '40%',
                'align' => 'left',
                'weight' => 'bold'
            ],
            [
                'title' => 'PU HT',
                'width' => '12%',
                'align' => 'right',
                'weight' => 'bold'
            ],
            [
                'title' => 'Qté',
                'width' => '7%',
                'align' => 'center',
                'weight' => 'bold'
            ],
            [
                'title' => 'Total HT',
                'width' => '13%',
                'align' => 'right',
                'weight' => 'bold'
            ],
            [
                'title' => 'TVA',
                'width' => '7%',
                'align' => 'center',
                'weight' => 'bold'
            ],
            [
                'title' => 'Total TTC',
                'width' => '13%',
                'align' => 'right',
                'weight' => 'bold'
            ],
        ],
        'credit' => [
            [
                'title' => 'Désignation',
                'width' => '40%',
                'align' => 'left',
                'weight' => 'bold'
            ],
            [
                'title' => 'PU HT',
                'width' => '12%',
                'align' => 'right',
                'weight' => 'bold'
            ],
            [
                'title' => 'Qté',
                'width' => '7%',
                'align' => 'center',
                'weight' => 'bold'
            ],
            [
                'title' => 'Total HT',
                'width' => '13%',
                'align' => 'right',
                'weight' => 'bold'
            ],
            [
                'title' => 'TVA',
                'width' => '7%',
                'align' => 'center',
                'weight' => 'bold'
            ],
            [
                'title' => 'Total TTC',
                'width' => '13%',
                'align' => 'right',
                'weight' => 'bold'
            ],
        ]
    ];
    

    public function customerInvoiceUnpaid(int $location)
    {
        return AccountingDocument::query()
            ->where('document_type', 'invoice')
            ->where('document_for', 'customer')
            ->where('location_id', $location)
            ->where('total_ttc', '>', 0)
            ->whereDate('accounting_document_release_date', '<', date_now()) // Correction ici
            ->where(function ($query) {
                $query->whereDoesntHave('payments') // Facture sans paiement
                    ->orWhereHas('payments', function ($subQuery) {
                        $subQuery->selectRaw('SUM(amount)')->havingRaw('SUM(amount) < accounting_documents.total_ttc');
                    }); // Facture avec paiement partiel
            })
            ->get();
    }
    
    public function customerInvoiceAwaitingPayment(int $location)
    {
        return AccountingDocument::query()
            ->where('document_type', 'invoice')
            ->where('document_for', 'customer')
            ->where('location_id', $location)
            ->where('total_ttc', '>', 0)
            ->whereColumn('accounting_document_release_date', '>', 'accounting_document_date') // Correction ici
            ->where(function ($query) {
                $query->whereDoesntHave('payments') // Facture sans paiement
                    ->orWhereHas('payments', function ($subQuery) {
                        $subQuery->selectRaw('SUM(amount)')->havingRaw('SUM(amount) < accounting_documents.total_ttc');
                    }); // Facture avec paiement partiel
            })
            ->get();
    }

    public function printdocument(string $type, string $slug){        
        $item = $this->documents($type, ['slug' => $slug])->first();        
        $ref = $item->reference;
        $name = str_replace(" ", "_", $ref).".pdf";

        $path = public_path("pdf/$type");
        $location = Location::where('id', $item->location_id)->first()->toArray();
        
        $detail['customer'] = $item->toArray();
        if($type == 'invoice'){
            $invoice = (new Invoice())->invoices([
                'document_id' => $item->id
            ])[0]->toArray();
            
            $parent = Location::where('is_parent', 1)->first();
            $invoice['document_logo'] = $parent->logo;
            $invoice['document_header'] = $parent->header;
            $invoice['document_footer'] = $parent->footer;
            
            $detail['site'] = $invoice;            
        }

        #dd($detail);

        $pdf = PDF::loadView('documents.index', [
            'cols' => $this->cols,
            'document' => [
                'type' => $type,
                'label' => AccountingDocService::documenttype()[$type]
            ],
            'detail' => $detail,            
        ]);

        $pdf->setOptions([
            'isHtml5ParserEnabled' => true,
            'isRemoteEnabled' => true,
            'isPhpEnabled' => true,
        ]);
    
        // Add footer using DomPDF callbacks
        $pdf->setPaper('a4');
        $pdf->output();
        $pdf->getDomPDF();
    
        $footerHtml = View::make('documents.partials.footer', [
            'footer' => nl2br($item->document_footer)
        ])->render();

        // Convertir le HTML en texte brut
        $footer_text = strip_tags($footerHtml);
        #dd($footer_text, $footerHtml);
        
        // Ajouter le pied de page
        $pdf->getDomPDF()->getCanvas()->page_script(function ($pageNumber, $pageCount, $canvas, $fontMetrics) use ($footerHtml) {
            // Convertir <br> en sauts de ligne pour DomPDF
            $footer_text = strip_tags($footerHtml);  // Enlever les balises HTML
            $lines = explode("\n", $footer_text);    // Diviser le texte en lignes par saut de ligne
            
            $size = 8;
            $width = $canvas->get_width();
            $height = $canvas->get_height();
            
            // Charger une police intégrée
            $font = $fontMetrics->getFont("helvetica", "normal");
            
            // Dessiner la ligne du pied de page
            $canvas->line(20, $height - 45, $width - 20, $height - 45, array(0, 0, 0), 0.1); // Ligne horizontale du bas
            
            foreach ($lines as $index => $line) {
                $text = trim($line);
                if ($text === '') {
                    continue; // Sauter les lignes vides
                }
                $textWidth = $fontMetrics->getTextWidth($text, $font, $size); // Largeur du texte
                $x = ($width - $textWidth) / 2; // Centrer le texte horizontalement
                $y = $height - 20 - ($index * 10); // Ajuster la position verticale pour chaque ligne
                $canvas->text($x, $y, $text, $font, $size, [0, 0, 0]);
            }
        });
        
        
        if (!File::exists("$path/$name")) {
            if (!File::isDirectory($path)) {
                File::makeDirectory($path, 0777, true, true);
            }
                    
            $pdf->save("$path/$name");
        }

        return [
            'pdf' => $pdf,
            'name' => $name
        ];
    }

    
}