<?php

namespace modules\sales\services;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Session;
use modules\sales\Models\Caisse;
use modules\sales\Models\CaisseStatus;
use modules\sales\Models\CaisseStory;
use modules\sales\Models\CaisseTransaction;
use modules\sales\Models\CaisseUser;

class CaisseService
{
    public static function status(int $caisse_id) : array{
        $last = CaisseStatus::where('caisse_id', $caisse_id)->latest('id')->first();        
        if(!is_null($last)){
            $caisse = CaisseStatus::find($last)->first();
            if (is_null($caisse)) {
                return [
                    'status' => 'close'                
                ];
            }
            return [
                'status' => 'open',
                'amount' => $caisse->amount,
                'fond_caisse' => $caisse->fond_caisse, 
                'date_begin' => $caisse->date_begin,       
                'date_end' => $caisse->date_end,
                'user_id' => $caisse->user_id,
                'user' => $caisse->user,
            ];
        }else{
            return [
                'status' => 'close'                
            ];
        }
    }

    public static function open(Request $request){
        try {
            

            $user = Auth::user();
            
            $date = $request->date;
            $daty = $date['date'].' '.$date['time'];
            
            Session::put("caisse_id", $request->caisse['id']);                
            Session::save();

            if($request->is_open){
                $caisse = CaisseStatus::where([
                    'location_id' => $request->location['id'],
                    'caisse_id' => $request->caisse['id'],
                ])->orderByDesc('created_at')->first();                

                Session::put("caisse_open_id", $caisse->id);
                Session::save();

                $caisse_status_id = $caisse->id;
                $token = $caisse->token;

                if($caisse->user_id != $user->id){
                    DB::beginTransaction();

                    $description = "Réouverture de caisse";
                    CaisseStory::create([
                        'caisse_status_id' => $caisse_status_id,
                        'description' => $description,
                        'user_id' => $user->id,
                        'user' => $user->name,
                        'amount_in' => 0,
                        'sold' => $caisse->amount,
                        'date_action' => $daty,
                        'token' => $token,
                        'created_at' => date_now(),
                        'updated_at' => date_now(),
                    ]);

                    CaisseUser::create([
                        'caisse_status_id' => $caisse_status_id,
                        'user_id' => $user->id,
                        'user' => $user->name,
                        'amount_start' => $caisse->amount,            
                        'created_at' => date_now(),
                        'updated_at' => date_now(),
                    ]);

                    DB::commit();
                }
                
                return [
                    'caisse' => [
                        'status' => 'open',
                        'data' => [
                            'id' => $caisse->caisse_id,
                            'title' => $caisse->caisse,
                        ],
                        'fond_caisse' => $caisse->amount,
                        'amount' => $caisse->amount
                    ],            
                ];

            }else{
                DB::beginTransaction();

                $amount = $request->amount;
                $token = generateString(18);                

                $caisse = CaisseStatus::create([
                    'location_id' => $request->location['id'],
                    'location' => $request->location['title'],
                    'caisse_id' => $request->caisse['id'],
                    'caisse' => $request->caisse['title'],
                    'user_id' => $user->id,
                    'user' => $user->name,
                    'amount' => $request->amount,
                    'fond_caisse' => $amount,
                    'date_begin' => $daty,
                    'token' => $token,
                    'status' => "open",
                    'created_at' => date_now(),
                    'updated_at' => date_now(),
                ]);

                $caisse_status_id = $caisse->id;

                Session::put("caisse_open_id", $caisse->id);
                Session::save();

                $description = "Ouverture de caisse";
                CaisseStory::create([
                    'caisse_status_id' => $caisse_status_id,                        
                    'description' => $description,
                    'user_id' => $user->id,
                    'user' => $user->name,
                    'amount_in' => $amount,
                    'sold' => $amount,
                    'date_action' => $daty,
                    'token' => $token,
                    'created_at' => date_now(),
                    'updated_at' => date_now(),
                ]);

                CaisseUser::create([
                    'caisse_status_id' => $caisse_status_id,
                    'user_id' => $user->id,
                    'user' => $user->name,
                    'amount_start' => $amount,            
                    'created_at' => date_now(),
                    'updated_at' => date_now(),
                ]);

                CaisseTransaction::create([
                    'caisse_status_id',
                    'type' => 'depot',
                    'amount' => $amount,
                    'date_transaction' => $daty,
                    'description' => $description,
                    'user_id' => $user->id,
                    'user' => $user->name,
                    'created_at' => date_now(),
                    'updated_at' => date_now(),
                ]);
            }
        
            DB::commit();

            return [
                'caisse' => [
                    'status' => 'open',
                    'data' => [
                        'id' => $request->caisse['id'],
                        'title' => $request->caisse['title'],
                    ],
                    'fond_caisse' => $amount,
                    'amount' => $amount
                ],            
            ];
        } catch (\Throwable $th) {
            DB::rollBack();
            throw $th;
        }
    }
}