import { defineConfig } from 'vite';
import laravel from 'laravel-vite-plugin';
import vue from '@vitejs/plugin-vue';
import path from 'path';
import fs from 'fs';

// Fonction pour récupérer dynamiquement les entrées des modules
const getModuleInputs = () => {
    const modulesDir = path.resolve(__dirname, 'modules');
    const moduleInputs = {};

    // Vérifie si le dossier des modules existe
    if (fs.existsSync(modulesDir)) {
        const modules = fs.readdirSync(modulesDir).filter((dir) => {
            return fs.statSync(path.join(modulesDir, dir)).isDirectory();
        });

        // Itère sur chaque dossier de module et construit le chemin
        modules.forEach((module) => {
            const modulePath = path.join(modulesDir, module, 'resources/js/app.js');
            if (fs.existsSync(modulePath)) {
                moduleInputs[module] = modulePath;
            }
        });
    }

    return moduleInputs;
};

export default defineConfig({
    plugins: [
        laravel({
            input: [
                'resources/css/app.css',  // CSS principal
                'resources/js/app.js',    // JS principal
                ...Object.values(getModuleInputs()), // Ajoute les entrées JS des modules
            ],
            refresh: true, // Rafraîchissement automatique
        }),
        vue({
            template: {
                transformAssetUrls: {
                    base: null,
                    includeAbsolute: false,
                },
            },
        }),
    ],
    build: {
        rollupOptions: {
            input: {
                main: path.resolve(__dirname, 'resources/js/app.js'), // Entrée principale
                ...getModuleInputs(), // Ajout des modules
            },
        },
    },
    resolve: {
        alias: {
            vue: 'vue/dist/vue.esm-bundler.js',
            '@': path.resolve(__dirname, 'resources/js'), // Alias pour un chemin plus court
        },
    },
});
